package com.steerinfo.dil.controller;

import com.steerinfo.dil.feign.AmsFeign;
import com.steerinfo.framework.controller.RESTfulResult;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiOperation;
import io.swagger.models.auth.In;
import oracle.jdbc.proxy.annotation.Post;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.math.BigDecimal;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @author luobang
 * @create 2021-09-17 14:10
 */
@RestController
@RequestMapping("${api.version}/ams")
public class AMScontroller{

    @Autowired
    AmsFeign amsFeign;

    @ApiOperation(value="查询运输预约")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(79)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getAllPurPlan")
    public Map<String, Object> getAllPurPlan(@RequestBody(required = false) Map<String, Object> mapValue,
                                       Integer apiId,
                                       Integer pageNum,
                                       Integer pageSize,
                                       Integer status,String con) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return amsFeign.getAllPurPlan(mapValue, apiId, pageNum, pageSize, status, con);
    }

    @ApiOperation(value = "通过Id查询请车作业")
    @PostMapping("/getPurPlanById/{planId}")
    public Map<String, Object> getPurPlanById(@PathVariable("planId") Integer planId) {
        return amsFeign.getPurPlanById(planId);
    }

    @ApiOperation(value = "新增运输计划 状态：0")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "amstruckPurplan", value = "运输计划实绩对象", required = false, dataType = "AmstruckPurplan"),
    })
    @PostMapping("/addPurPlan")
    public Map<String, Object> addPurPlan(@RequestBody Map<String, Object> map) {
        return amsFeign.addPurPlan(map);
    }

    @ApiOperation(value="修改运输计划")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "amstruckPurplan", value = "请车作业实绩对象", required = false, dataType = "AmstruckPurplan"),
    })
    @PostMapping("/updatePurPlan")
    public Map<String, Object> updatePurPlan(@RequestBody Map<String, Object> amstruckPurplan){
        return amsFeign.updatePurPlan(amstruckPurplan);
    }
    
    @ApiOperation(value = "下发运输计划 状态：1")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "planId", value = "运输计划Id", required = false, dataType = "Integer"),
    })
    @PostMapping("/sendPurPlan/{planId}")
    public Map<String, Object> sendPurPlan(@PathVariable("planId") Integer planId) {
        return amsFeign.sendPurPlan(planId);
    }

    @ApiOperation(value = "接收运输计划 状态：2")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "planId", value = "运输计划Id", required = false, dataType = "Integer"),
    })
    @PostMapping("/receptionPurPlan/{planId}")
    public Map<String, Object> receptionPurPlan(@PathVariable("planId") Integer planId) {
        return amsFeign.receptionPurPlan(planId);
    }

    //停用运输计划
    @PostMapping("/changePlanStatus/{planId}")
    public Map<String,Object>changePlanStatus(@PathVariable("planId") BigDecimal planId){
        return amsFeign.changePlanStatus(planId);
    }



    @ApiOperation(value = "逻辑删除运输计划 状态：3")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "planId", value = "运输计划Id", required = false, dataType = "Integer"),
    })
    @PostMapping("/deletePurPlan/{planId}")
    public Map<String, Object> deletePurPlan(@PathVariable("planId") Integer planId) {
        return amsFeign.deletePurPlan(planId);
    }

    //**************************************************************************************
    @ApiOperation(value = "查询要分派的计划")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(82)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("/getDecomposedPlan")
    public Map<String, Object> getDecomposedPlan(@RequestBody(required = false) Map<String, Object> mapValue,
                                           Integer apiId,
                                           Integer pageNum,
                                           Integer pageSize,
                                           Integer planId,
                                           Integer status,
                                                 Integer planStatus,
                                                 String con) {
        return amsFeign.getDecomposedPlan(mapValue == null? new HashMap<>() : mapValue, apiId, pageNum, pageSize, planId, status, planStatus, con);
    }


    /**
     * 违约规则
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping("getBreachList")
    @ApiOperation(value = "展示违约列表")
    public Map<String, Object> getBreachList(@RequestBody(required = false) Map<String, Object> mapValue,
                                       Integer pageNum,
                                       Integer pageSize,
                                       Integer apiId) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return amsFeign.getBreachList(mapValue, pageNum, pageSize, apiId);
    }

    @PostMapping("addContractBreach")
    @ApiOperation(value = "新增违约规则")
    Map<String, Object> addContractBreach(@RequestBody Map<String, Object> amsContractBreach) {
        return amsFeign.addContractBreach(amsContractBreach);
    }

    @PostMapping("deleteContractBreach/{breachId}")
    @ApiOperation(value = "逻辑删除违约规则")
    Map<String, Object> deleteContractBreach(@PathVariable("breachId") BigDecimal breachId) {
        return amsFeign.deleteContractBreach(breachId);
    }

    @PostMapping("updateContractBreach")
    @ApiOperation(value = "修改违约规则")
    Map<String, Object> updateContractBreach(@RequestBody Map<String, Object> amsContractBreach) {
        return amsFeign.updateContractBreach(amsContractBreach);
    }

    @PostMapping("selectBreachToUpdate/{breachId}")
    @ApiOperation(value = "查询违约规则")
    Map<String, Object> selectBreachToUpdate(@PathVariable("breachId") BigDecimal breachId) {
        return amsFeign.selectBreachToUpdate(breachId);
    }


    /**
     * 港口装卸单价
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping("getLoadUnloadPriceList")
    @ApiOperation(value = "展示港口装卸单价列表")
    public Map<String, Object> getLoadUnloadPriceList(@RequestBody(required = false) Map<String, Object> mapValue,
                                                Integer pageNum,
                                                Integer pageSize,
                                                Integer apiId) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return amsFeign.getLoadUnloadPriceList(mapValue, pageNum, pageSize, apiId);
    }

    @PostMapping("addLoadUnloadPrice")
    @ApiOperation(value = "新增港口装卸单价")
    Map<String, Object> addLoadUnloadPrice(@RequestBody Map<String, Object> amsContractOtherPrice) {
        return amsFeign.addLoadUnloadPrice(amsContractOtherPrice);
    }

    @PostMapping("deleteLoadUnloadPrice/{priceId}")
    @ApiOperation(value = "逻辑删除港口装卸单价")
    Map<String, Object> deleteLoadUnloadPrice(@PathVariable("priceId") BigDecimal priceId) {
        return amsFeign.deleteLoadUnloadPrice(priceId);
    }

    @PostMapping("updateLoadUnloadPrice")
    @ApiOperation(value = "修改港口装卸单价")
    Map<String, Object> updateLoadUnloadPrice(@RequestBody Map<String, Object> amsContractOtherPrice) {
        return amsFeign.updateLoadUnloadPrice(amsContractOtherPrice);
    }

    @PostMapping("selectLoadUnloadPriceToUpdate/{priceId}")
    @ApiOperation(value = "查询港口装卸单价")
    Map<String, Object> selectLoadUnloadPriceToUpdate(@PathVariable("priceId") BigDecimal priceId) {
        return amsFeign.selectLoadUnloadPriceToUpdate(priceId);
    }


    /**
     * 火运单价
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping("getTrainPriceList")
    @ApiOperation(value = "展示火运单价列表")
    public Map<String, Object> getTrainPriceList(@RequestBody(required = false) Map<String, Object> mapValue,
                                           Integer pageNum,
                                           Integer pageSize,
                                           Integer apiId) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return amsFeign.getTrainPriceList(mapValue, pageNum, pageSize, apiId);
    }

    @PostMapping("addTrainPrice")
    @ApiOperation(value = "新增火运单价")
    Map<String, Object> addTrainPrice(@RequestBody Map<String, Object> amsContractTrainPrice) {
        return amsFeign.addTrainPrice(amsContractTrainPrice);
    }

    @PostMapping("deleteTrainPrice/{priceId}")
    @ApiOperation(value = "逻辑删除火运单价")
    Map<String, Object> deleteTrainPrice(@PathVariable("priceId") BigDecimal priceId) {
        return amsFeign.deleteTrainPrice(priceId);
    }

    @PostMapping("updateTrainPrice")
    @ApiOperation(value = "修改火运单价")
    Map<String, Object> updateTrainPrice(@RequestBody Map<String, Object> amsContractTrainPrice) {
        return amsFeign.updateTrainPrice(amsContractTrainPrice);
    }

    @PostMapping("selectTrainPriceToUpdate/{priceId}")
    @ApiOperation(value = "通过id查询火运单价")
    Map<String, Object> selectTrainPriceToUpdate(@PathVariable("priceId") BigDecimal priceId) {
        return amsFeign.selectTrainPriceToUpdate(priceId);
    }

    /**
     * 运费单价
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping("getShipPriceList")
    @ApiOperation(value = "展示水运单价列表")
    public Map<String, Object> getShipPriceList(@RequestBody(required = false) Map<String, Object> mapValue,
                                          Integer pageNum,
                                          Integer pageSize,
                                          Integer apiId) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return amsFeign.getShipPriceList(mapValue, pageNum, pageSize, apiId);
    }

    @PostMapping("addShipPrice")
    @ApiOperation(value = "新增水运单价")
    Map<String, Object> addShipPrice(@RequestBody Map<String, Object> amsContractTransportPrice) {
        return amsFeign.addShipPrice(amsContractTransportPrice);
    }

    @PostMapping("deleteShipPrice/{priceId}")
    @ApiOperation(value = "逻辑删除运费单价")
    Map<String, Object> deleteShipPrice(@PathVariable("priceId") BigDecimal priceId) {
        return amsFeign.deleteShipPrice(priceId);
    }

    @PostMapping("updateShipPrice")
    @ApiOperation(value = "修改水运单价")
    Map<String, Object> updateShipPrice(@RequestBody Map<String, Object> amsContractTransportPrice) {
        return amsFeign.updateShipPrice(amsContractTransportPrice);
    }

    @PostMapping("selectPriceToUpdate/{priceId}")
    @ApiOperation(value = "通过id查询运费单价")
    Map<String, Object> selectPriceToUpdate(@PathVariable("priceId") BigDecimal priceId) {
        return amsFeign.selectPriceToUpdate(priceId);
    }

    @PostMapping("getTruckPriceList")
    @ApiOperation(value = "展示汽运单价列表")
    public Map<String, Object> getTruckPriceList(@RequestBody(required = false) Map<String, Object> mapValue,
                                           Integer pageNum,
                                           Integer pageSize,
                                           Integer apiId) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return amsFeign.getTruckPriceList(mapValue, pageNum, pageSize, apiId);
    }

    @PostMapping("addAmsContractTransportPrice")
    @ApiOperation(value = "新增汽运单价")
    Map<String, Object> addAmsContractTransportPrice(@RequestBody Map<String, Object> amsContractTransportPrice) {
        return amsFeign.addAmsContractTransportPrice(amsContractTransportPrice);
    }

    @PostMapping("updateAmsContractTransportPrice")
    @ApiOperation(value = "修改汽运单价")
    Map<String, Object> updateAmsContractTransportPrice(@RequestBody Map<String, Object> amsContractTransportPrice) {
        return amsFeign.updateAmsContractTransportPrice(amsContractTransportPrice);
    }


    @PostMapping("getPurchaseOrderList")
    @ApiOperation(value = "展示采购订单列表")
    public Map<String, Object> getPurchaseOrderList(@RequestBody(required = false) Map<String, Object> mapValue,
                                              Integer pageNum,
                                              Integer pageSize,
                                              Integer apiId,
                                              String con,String sendCompId) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return amsFeign.getPurchaseOrderList(mapValue, pageNum, pageSize, apiId, con, sendCompId);
    }

    /**
     * 获取收货地址
     * @return
     */
    @PostMapping("getAddressDeliveryAddress")
    @ApiOperation(value = "得到地址下拉")
    @ApiImplicitParam(name = "apiId",value = "255")
    public Map<String, Object> getAddressDeliveryAddress(@RequestBody(required=false) Map<String,Object> mapValue,
                                                         Integer apiId,
                                                         Integer pageNum,
                                                         Integer pageSize,
                                                         String con){
        return amsFeign.getAddressDeliveryAddress(mapValue==null?new HashMap<>():mapValue, apiId, pageNum, pageSize,con);
    }

    @GetMapping("getShipperId")
    @ApiOperation(value = "得到托运人下拉")
    public Map<String, Object> getShipperId(){
        return amsFeign.getShipperId();
    }

    @GetMapping("getCarrierId")
    @ApiOperation(value = "得到承运商下拉")
    public Map<String, Object> getCarrierId(){
        return amsFeign.getCarrierId();
    }

    @GetMapping("getCapacityId")
    @ApiOperation(value = "获取船id下拉列表")
    public Map<String, Object> getCapacityId(){
        return amsFeign.getCapacityId();
    }

    @GetMapping("getMaterialId")
    @ApiOperation(value = "得到物资下拉")
    public Map<String, Object> getMaterialId(){
        return amsFeign.getMaterialId();
    }

    @GetMapping("getTruckCapacityId")
    @ApiOperation(value = "得到车牌号下拉")
    public Map<String, Object> getTruckCapacityId(){
        return amsFeign.getTruckCapacityId();
    }

    @GetMapping("getLineId")
    @ApiOperation(value = "获取运输线路下拉列表")
    public Map<String, Object> getLineId(){
        return amsFeign.getLineId();
    }
// ----------------------------------销售合同-------------------------------------------
    /**
     * 查询汽运单价信息
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping("/getAmsContractTransportPrice1")
    @ApiOperation(value = "查询汽运单价信息")
    public Map<String, Object> getAmsContractTransportPrice1(@RequestBody(required = false) Map<String, Object> mapValue,
                                                             Integer pageNum,
                                                             Integer pageSize,
                                                             Integer apiId,
                                                             Integer deleted) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return amsFeign.getAmsContractTransportPrice1(mapValue, pageNum, pageSize, apiId, deleted);
    }

    @PostMapping("/getInwardContractPrice")
    @ApiOperation(value = "查询内转汽运单价信息")
    public Map<String, Object> getInwardContractPrice(@RequestBody(required = false) Map<String, Object> mapValue,
                                                             Integer pageNum,
                                                             Integer pageSize,
                                                             Integer apiId,
                                                             Integer deleted) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return amsFeign.getInwardContractPrice(mapValue, pageNum, pageSize, apiId, deleted);
    }


    /**
     * 新增汽运单价
     * @param mapVal
     * @return
     */
    @PostMapping("addAmsContractTransportUnitPrice1")
    @ApiOperation(value = "新增汽运单价")
    Map<String, Object> addAmsContractTransportUnitPrice1(@RequestBody Map<String, Object> mapVal) {
        return amsFeign.addAmsContractTransportUnitPrice1(mapVal);
    }


    @PostMapping("insertInwardPrice")
    @ApiOperation(value = "新增内转运输单价")
    Map<String, Object> insertInwardPrice(@RequestBody Map<String, Object> mapVal) {
        return amsFeign.insertInwardPrice(mapVal);
    }

    @PostMapping("deleteAmsContractTransportPrice1")
    @ApiOperation(value = "通过主键id删除汽运单价")
    Map<String, Object> deleteAmsContractTransportPrice1(@RequestParam BigDecimal priceId) {
        return amsFeign.deleteAmsContractTransportPrice1(priceId);
    }

    /**
     * 通过主键修改汽运单价
     */
    @PostMapping("updateAmsContractTransportPrice1")
    @ApiOperation(value = "通过主键id修改汽运单价")
    Map<String, Object> updateAmsContractTransportPrice1(@RequestBody(required = false) Map<String, Object> mapVal) {
        return amsFeign.updateAmsContractTransportPrice1(mapVal);
    }
    /**
     *通过主键渲染信息
     */
    @PostMapping(value = "/getAmsContractTransportPriceByPriceId1")
    Map<String, Object> getAmsContractTransportPriceByPriceId1(@RequestParam BigDecimal priceId){
        return amsFeign.getAmsContractTransportPriceByPriceId1(priceId);
    }
    /**
     * 通过主键修改汽运单价
     */
    @PostMapping("batchUpdateTransportPriceByOilPrice1")
    @ApiOperation(value = "油价联动导致运价变动，批量修改运价")
    Map<String, Object> batchUpdateTransportPriceByOilPrice1(@RequestBody Map<String,Object> map) {
        return amsFeign.batchUpdateTransportPriceByOilPrice1(map);
    }
    @GetMapping("getLineNo")
    @ApiOperation(value = "得到线路编号下拉")
    public Map<String, Object> getLineNo(){
        return amsFeign.getLineNo();
    }
    @GetMapping("getCapacityNumber")
    @ApiOperation(value = "得到运力编号下拉")
    public Map<String, Object> getCapacityNumber(){
        return amsFeign.getCapacityNumber();
    }
    @GetMapping("getDeliveryAddress")
    @ApiOperation(value = "得到收货地址下拉")
    public Map<String, Object> getDeliveryAddress(){
        return amsFeign.getDeliveryAddress();
    }

    @GetMapping("getCargoName")
    @ApiOperation(value = "获取货物类型")
    public Map<String, Object> getCargoName(){
        return amsFeign.getCargoName();
    }

    @GetMapping("getOilTypeName")
    @ApiOperation(value = "获取油品名称")
    public Map<String, Object> getOilTypeName(){
        return amsFeign.getOilTypeName();
    }

    @PostMapping("/addAmsDispatchSaleOrder")
    Map<String, Object> addAmsDispatchSaleOrder(@RequestBody(required = false) Map<String, Object> mapVal) {
        return amsFeign.addAmsDispatchSaleOrder(mapVal);
    }
    @GetMapping("getCarrierName")
    @ApiOperation(value = "得到承运商名称")
    public Map<String, Object> getCarrierName(){
        return amsFeign.getCarrierName();
    }
    @PostMapping("getSaleOrderInfo")
    @ApiOperation(value = "查询汽运单价信息")
    public Map<String, Object> getSaleOrderInfo(@RequestBody(required = false) Map<String, Object> mapValue,
                                                    Integer pageNum,
                                                    Integer pageSize,
                                                    Integer apiId) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return amsFeign.getSaleOrderInfo(mapValue, pageNum, pageSize, apiId);
    }

    @ApiOperation(value="查询已上报销售订单信息")
    @PostMapping("/getSaleOrderReported")
    Map<String, Object> getSaleOrderReported(@RequestBody(required = false) Map<String, Object> mapValue,
                                             @RequestParam Integer pageNum,
                                             @RequestParam Integer pageSize,
                                             @RequestParam Integer apiId){
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return amsFeign.getSaleOrderReported(mapValue,pageNum,pageSize,apiId);
    }
    @PostMapping("getAmsSaleOrderApproved")
    @ApiOperation(value = "查询财务已审批销售订单信息")
    public Map<String, Object> getAmsSaleOrderApproved(@RequestBody(required = false) Map<String, Object> mapValue,
                                          Integer pageNum,
                                          Integer pageSize,
                                          Integer apiId) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return amsFeign.getAmsSaleOrderApproved(mapValue, pageNum, pageSize, apiId);
    }
    @PostMapping("getSaleOrderDetail")
    @ApiOperation(value = "查询汽运单价信息")
    public Map<String, Object> getSaleOrderDetail(@RequestParam BigDecimal saleOrderId,@RequestBody(required = false) Map<String, Object> mapValue,
                                                 Integer pageNum,
                                                 Integer pageSize,
                                                 Integer apiId) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return amsFeign.getSaleOrderDetail(saleOrderId,mapValue, pageNum, pageSize, apiId);
    }
    @PostMapping("uploadSaleOrder")
    Map<String, Object> uploadSaleOrder(@RequestParam BigDecimal saleOrderId) {
        return amsFeign.uploadSaleOrder(saleOrderId);
    }
    @PostMapping("/addAmsSaleOrder")
    Map<String, Object> addAmsSaleOrder(@RequestBody(required = false) Map<String, Object> mapVal) {
        return amsFeign.addAmsSaleOrder(mapVal==null?new HashMap<>():mapVal);
    }
    @PostMapping("getAmsSaleOrderBySaleOrderId")
    Map<String, Object> getAmsSaleOrderBySaleOrderId(@RequestParam BigDecimal saleOrderId) {
        return amsFeign.getAmsSaleOrderBySaleOrderId(saleOrderId);
    }
    @PostMapping("/updateAmsSaleOrder")
    Map<String, Object> updateAmsSaleOrder(@RequestBody(required = false) Map<String, Object> mapVal) {
        return amsFeign.updateAmsSaleOrder(mapVal);
    }
    @PostMapping("deleteAmsSaleOrderBySaleOrderId")
    Map<String, Object> deleteAmsSaleOrderBySaleOrderId(@RequestParam BigDecimal saleOrderId) {
        return amsFeign.deleteAmsSaleOrderBySaleOrderId(saleOrderId);
    }
    @PostMapping("getSaleOrderUpdateLog")
    @ApiOperation(value = "查询汽运单价信息")
    public Map<String, Object> getSaleOrderUpdateLog(BigDecimal saleOrderId,@RequestBody(required = false) Map<String, Object> mapValue,
                                            Integer pageNum,
                                            Integer pageSize,
                                            Integer apiId) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return amsFeign.getSaleOrderUpdateLog(saleOrderId,mapValue, pageNum, pageSize, apiId);
    }
    @GetMapping(value = "getSalePlanName")
    @ApiOperation(value="获取销售计划名称")
    public Map<String, Object> getSalePlanName(){return amsFeign.getSalePlanName();}
    @GetMapping("getShipperName")
    @ApiOperation(value = "得到发货单位下拉")
    public Map<String, Object> getShipperName(){
        return amsFeign.getShipperName();
    }
    @GetMapping("getConsigneeCompanyName")
    @ApiOperation(value = "得到收货单位下拉")
    public Map<String, Object> getConsigneeCompanyName(){
        return amsFeign.getConsigneeCompanyName();
    }
    @PostMapping("addAmsSaleOrderMaterial")
    Map<String, Object> addAmsSaleOrderMaterial(@RequestBody(required = false) Map<String,Object> map) {
        return amsFeign.addAmsSaleOrderMaterial(map);
    }
    @PostMapping("getAmsSaleOrderMaterialBySaleOrderMaterialId")
    Map<String, Object> getAmsSaleOrderMaterialBySaleOrderMaterialId(@RequestParam BigDecimal saleOrderMaterialId) {
        return amsFeign.getAmsSaleOrderMaterialBySaleOrderMaterialId(saleOrderMaterialId);
    }
    @ApiOperation(value="通过主键修改销售订单物资信息")
    @PostMapping(value = "/updateAmsSaleOrderMaterial")
    Map<String, Object> updateAmsSaleOrderMaterial(@RequestBody(required = false) Map<String,Object> map){
        return amsFeign.updateAmsSaleOrderMaterial(map);
    }
    @PostMapping("deleteAmsSaleOrderMaterialBySaleOrderMaterialId")
    Map<String, Object> deleteAmsSaleOrderMaterialBySaleOrderMaterialId(BigDecimal saleOrderMaterialId) {
        return amsFeign.deleteAmsSaleOrderMaterialBySaleOrderMaterialId(saleOrderMaterialId);
    }
    @PostMapping("getAddress")
    Map<String, Object> getAddress(BigDecimal saleOrderMaterialId) {
        return amsFeign.getAddress(saleOrderMaterialId);
    }
    @PostMapping("updateAddress")
    Map<String, Object> updateAddress(@RequestBody(required = false)Map<String,Object> map) {
        return amsFeign.updateAddress(map);
    }
    @PostMapping("getSalePlanInfo")
    @ApiOperation(value = "查询汽运单价信息")
    public Map<String, Object> getSalePlanInfo(@RequestBody(required = false) Map<String, Object> mapValue,
                                               Integer pageNum,
                                               Integer pageSize,
                                               Integer apiId) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return amsFeign.getSalePlanInfo(mapValue, pageNum, pageSize, apiId);
    }
    @PostMapping("addAmsSalePlan")
    Map<String, Object> addAmsSalePlan(@RequestBody(required = false)Map<String,Object> map) {
        return amsFeign.addAmsSalePlan(map);
    }
    @PostMapping("getAmsSalePlanByPlanId")
    Map<String, Object> getAmsSalePlanByPlanId(@RequestParam BigDecimal planId) {
        return amsFeign.getAmsSalePlanByPlanId(planId);
    }
    @PostMapping("upadteAmsSalePlanByPlanId")
    Map<String, Object> upadteAmsSalePlanByPlanId(@RequestBody(required = false)Map<String,Object> map) {
        return amsFeign.upadteAmsSalePlanByPlanId(map);
    }
    @PostMapping("deleteAmsSalePlanByPlanId")
    Map<String, Object> deleteAmsSalePlanByPlanId(@RequestParam BigDecimal planId) {
        return amsFeign.deleteAmsSalePlanByPlanId(planId);
    }
    @GetMapping("getMaterialName")
    @ApiOperation(value = "得到收货单位下拉")
    public Map<String, Object> getMaterialName(){
        return amsFeign.getMaterialName();
    }
    @GetMapping("getAreaName")
    @ApiOperation(value = "得到收货单位下拉")
    public Map<String, Object> getAreaName(){
        return amsFeign.getAreaName();
    }


    @PostMapping("getSalePlanMaterialInfo")
    @ApiOperation(value="查询销售计划物资信息")
    public Map<String, Object> getSalePlanMaterialInfo(@RequestParam BigDecimal planId,@RequestBody(required=false) Map<String,Object> mapValue,
                                                @RequestParam Integer apiId,
                                                @RequestParam Integer pageNum,
                                                @RequestParam Integer pageSize){
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return amsFeign.getSalePlanMaterialInfo(planId,mapValue,apiId,pageNum,pageSize);
    }

    @PostMapping(value = "addAmsSalePlanMaterial")
    @ApiOperation(value="新增销售计划物资信息")
    public Map<String, Object> addAmsSalePlanMaterial(@RequestBody(required = false) Map<String, Object> map){
        return amsFeign.addAmsSalePlanMaterial(map);
    }

    @PostMapping(value = "deleteAmsSalePlanMaterial")
    @ApiOperation(value="通过主键删除销售计划物资信息")
    Map<String, Object> deleteAmsSalePlanMaterial(@RequestParam BigDecimal planMaterialId){
        return amsFeign.deleteAmsSalePlanMaterial(planMaterialId);
    }

    @PostMapping(value = "/getAmsSalePlanMaterialByPlanMaterialId")
    @ApiOperation(value="通过主键查询销售计划物资信息")
    Map<String, Object> getAmsSalePlanMaterialByPlanMaterialId(@RequestParam BigDecimal planMaterialId){
        return amsFeign.getAmsSalePlanMaterialByPlanMaterialId(planMaterialId);
    }

    @PostMapping(value = "/upadteAmsSalePlanMaterial")
    @ApiOperation(value="通过主键修改销售计划物资信息")
    Map<String, Object> upadteAmsSalePlanMaterial(@RequestBody(required = false) Map<String, Object> map){
        return amsFeign.upadteAmsSalePlanMaterial(map);
    }

    @PostMapping("/getTruckNoDetail")
    @ApiOperation(value="查询销售订单车序号详细信息")
    Map<String, Object> getTruckNoDetail(@RequestParam BigDecimal saleOrderMaterialId,@RequestBody(required=false) Map<String,Object> mapValue,
                                         @RequestParam Integer apiId,
                                         @RequestParam Integer pageNum,
                                         @RequestParam Integer pageSize){
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return amsFeign.getTruckNoDetail(saleOrderMaterialId,mapValue,apiId,pageNum,pageSize);
    }

    @ApiOperation(value="新增车序号物资信息")
    @PostMapping(value = "/addAmsSaleTrucknoMaterial")
    Map<String, Object> addAmsSaleTrucknoMaterial(@RequestBody(required = false) Map<String, Object> map){
        return amsFeign.addAmsSaleTrucknoMaterial(map);
    }

    @ApiOperation(value="通过主键删除车序号物资信息")
    @PostMapping(value = "/deleteAmsSaleTrucknoMaterial")
    Map<String, Object> deleteAmsSaleTrucknoMaterial(@RequestParam BigDecimal trucknoMaterialId){
        return amsFeign.deleteAmsSaleTrucknoMaterial(trucknoMaterialId);
    }

    @ApiOperation(value="通过主键渲染车序号物资信息")
    @PostMapping(value = "/getAmsSaleTrucknoMaterial")
    Map<String, Object> getAmsSaleTrucknoMaterial(@RequestParam BigDecimal trucknoMaterialId){
        return amsFeign.getAmsSaleTrucknoMaterial(trucknoMaterialId);
    }

    @ApiOperation(value="通过主键修改车序号物资信息")
    @PostMapping(value = "/updateAmsSaleTrucknoMaterial")
    Map<String, Object> updateAmsSaleTrucknoMaterial(@RequestBody(required = false) Map<String, Object> map){
        return amsFeign.updateAmsSaleTrucknoMaterial(map);
    }
    //************************************内转物流***************************************************
    @PostMapping("getAmsContractTransportPriceForConverted")
    @ApiOperation(value = "内转物流查询汽运单价信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "apiId(205)", value = "表头", required = false, dataType = "Interger")
    })
   public Map<String,Object> getAmsContractTransportPriceForConverted(@PathVariable("lineId")BigDecimal lineId,
                                         Integer apiId,
                                         Integer pageNum,
                                         Integer pageSize) {
        return amsFeign.getAmsContractTransportPriceForConverted(lineId, pageNum, pageSize, apiId);
    }
    /**
     * 下拉框显示线路
     */
    @ApiOperation(value="获取线路")
    @ApiImplicitParams({
    })
    @GetMapping(value = "/getLineRoute")
    public Map<String,Object> getLineRoute(){
        return amsFeign.getLineRoute();
    }

    //销售订单-固定派单-公开派单-日计划

    @ApiModelProperty(value = "展示销售公司已审核的订单")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "查询页数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "每页记录数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "apiId", value = "105", required = false, dataType = "BigDecimal")
    })
    @PostMapping("/getSaleOrderListBySaleCompany")
    public Map<String,Object> getSaleOrderListBySaleCompany(@RequestBody(required = false) Map<String,Object> mapValue,
                                                       Integer pageNum,
                                                       Integer pageSize,
                                                       Integer apiId,
                                                       String con){
      return   amsFeign.getSaleOrderListBySaleCompany(mapValue==null?new HashMap<>():mapValue, pageNum, pageSize, apiId, con);
    }




    //展示销售公司已审核销售订单的车序号列表
    @PostMapping("/getSaleOrderList")
    @ApiOperation(value = "查询汽运单价信息")
    public Map<String,Object> amsSaleOrderList(@RequestBody(required = false) Map<String, Object> mapValue,
                                          Integer pageNum,
                                          Integer pageSize,
                                          Integer apiId,
                                           Integer status    ) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return amsFeign.amsSaleOrderList(mapValue, pageNum, pageSize, apiId,status);
    }

    //固定派单：通过车序号查询收货地址，截取收货地址的区域，去资源管理中查询对应的承运商,将车序号与承运商绑定
    @PostMapping("/addFixedAmsDispatchSaleOrder")
    Map<String,Object> addFixedAmsDispatchSaleOrder(@RequestBody(required = false) List<Map<String,Object>> mapValue) {
        return amsFeign.addFixedAmsDispatchSaleOrder(mapValue);
    }

    //公开派单
    //查询未分派车辆的销售订单的车序号
    @PostMapping("/getAmsSaleOrderMaterial")
    @ApiOperation(value = "展示车序号列表")
    public Map<String,Object> getAmsSaleOrderMaterial(@RequestBody(required = false) Map<String, Object> mapValue,
                                                      Integer pageNum,
                                                      Integer pageSize,
                                                      Integer apiId,
                                                      Integer status) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return amsFeign.getAmsSaleOrderMaterial(mapValue, pageNum, pageSize, apiId,status);
    }

    //新增公开派单
    @PostMapping("/addOpenAmsDispatchSaleOrder/{orderMaterialId}")
    Map<String,Object> addOpenAmsDispatchSaleOrder(@PathVariable("orderMaterialId") BigDecimal orderMaterialId) {
        return amsFeign.addOpenAmsDispatchSaleOrder(orderMaterialId);
    }

    //删除公开派单
    @PostMapping("/deleteAmsDispatchSaleOrder/{dispatchId}")
    Map<String,Object> deleteAmsDispatchSaleOrder(@PathVariable("dispatchId") BigDecimal saleOrderId) {
        return amsFeign.deleteAmsDispatchSaleOrder(saleOrderId);
    }

    //展示公开派单
    @PostMapping("/getOpenDispatchSaleOrder")
    @ApiOperation(value = "公开派单")
    public Map<String,Object> getOpenDispatchSaleOrder(@RequestBody(required = false) Map<String, Object> mapValue,
                                                  Integer pageNum,
                                                  Integer pageSize,
                                                  Integer apiId) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return amsFeign.getOpenDispatchSaleOrder(mapValue, pageNum, pageSize, apiId);
    }

    //修改公开派单
    @PostMapping("/updateOpenDispatchSaleOrder")
    Map<String,Object> updateOpenDispatchSaleOrder(@RequestBody  Map<String, Object> mapVal) {
        return amsFeign.updateOpenDispatchSaleOrder(mapVal);
    }


    //焦炭、水渣日计划
    //新增
    @PostMapping("/addTruckRailDayPlan")
    public Map<String,Object> addTruckRailDayPlan(@RequestBody  Map<String, Object> mapVal) {
        return amsFeign.addTruckRailDayPlan(mapVal);
    }
    //删除
    @PostMapping("/deleteTruckRailDayPlan/{dayPlanId}")
    public Map<String,Object> deleteTruckRailDayPlan(@PathVariable("dayPlanId") BigDecimal dayPlanId) {
        return amsFeign.deleteTruckRailDayPlan(dayPlanId);
    }
    //修改
    @PostMapping("/updateTruckRailDayPlan")
    public Map<String,Object> updateTruckRailDayPlan(@RequestBody  Map<String, Object> mapVal) {
        return amsFeign.updateTruckRailDayPlan(mapVal);
    }
    @PostMapping("getDayPlanByDayPlanId/{dayplanId}")
    Map<String,Object> getDayPlanByDayPlanId(@PathVariable("dayplanId") Integer dayplanId){
        return amsFeign.getDayPlanByDayPlanId(dayplanId);
    }

    /**
     * 修改日期计划 2021年11月20日03:18:05
     * @param map
     * @return
     */
    @PostMapping("/updateDayPlan")
    public Map<String,Object> updateDayPlan(@RequestBody(required = false) Map<String, Object> map){
        return amsFeign.updateDayPlan(map);
    }

    /**
     * 查询所有的承运商
     * @return
     */
    @GetMapping("/getCarrierMes")
    public  Map<String,Object> getCarrierMes() {
        return amsFeign.getCarrierMes();
    }

    //展示日计划
    @PostMapping("/getTruckRailDayPlanList")
    @ApiOperation(value = "焦炭日计划")
    public Map<String, Object> getTruckRailDayPlan(@RequestBody(required = false) Map<String, Object> mapValue,
                                             Integer pageNum,
                                             Integer pageSize,
                                             Integer apiId,
                                                   Integer status) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return amsFeign.getTruckRailDayPlan(mapValue, pageNum, pageSize, apiId, status);
    }
    //展示日计划
    @PostMapping("/getSzTruckRailDayPlanList")
    @ApiOperation(value = "水渣日计划")
    public Map<String, Object> getSzTruckRailDayPlan(@RequestBody(required = false) Map<String, Object> mapValue,
                                               Integer pageNum,
                                               Integer pageSize,
                                               Integer apiId,
                                               Integer status) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return amsFeign.getSzTruckRailDayPlan(mapValue, pageNum, pageSize, apiId, status);
    }

    //新增钢材发往异地库计划
    @PostMapping("/addRailOffsetDayplan")
    public Map<String,Object> addRailOffsetDayplan(@RequestBody  Map<String, Object> mapVal){
        return amsFeign.addRailOffsetDayplan(mapVal);
    }
    //删除钢材发往异地库计划
    @PostMapping("/deleteRailOffsetDayplan/{dayplanId}")
    public Map<String,Object> deleteRailOffsetDayplan(@PathVariable("dayplanId") Integer dayplanId) {
        return amsFeign.deleteRailOffsetDayplan(dayplanId);
    }
    //修改钢材发往异地库计划
    @PostMapping("/updateRailOffsetDayplan")
    public Map<String,Object> updateRailOffsetDayplan(@RequestBody  Map<String, Object> mapVal){
        return amsFeign.updateRailOffsetDayplan(mapVal);
    }

    //钢材发运到异地库查询物资
    @PostMapping("/getMaterialMesByDayPlanId")
    public Map<String,Object> getMaterialMesByDayPlanId(@RequestBody(required = false) Map<String, Object> mapValue,
                                                        Integer pageNum,
                                                        Integer pageSize,
                                                        Integer apiId,
                                                        Integer dayplanId){
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return amsFeign.getMaterialMesByDayPlanId(mapValue,pageNum,pageSize,apiId,dayplanId);
    }

    //展示钢材发往异地库计划
    @PostMapping("/getRailOffsetDayplan")
    @ApiOperation(value = "展示钢材发往异地库计划")
    public Map<String, Object> getRailOffsetDayplan(@RequestBody(required = false) Map<String, Object> mapValue,
                                              Integer pageNum,
                                              Integer pageSize,
                                              Integer apiId,
                                              Integer dayplanReceiveStatus,
                                              Integer carrierId) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return amsFeign.getRailOffsetDayplan(mapValue, pageNum, pageSize, apiId,dayplanReceiveStatus,carrierId);
    }

    @PostMapping("/getRailOffsetDayplanId")
    @ApiOperation(value = "根据ID展示钢材发往异地库计划")
    public Map<String, Object> getRailOffsetDayplanId(@RequestBody(required = false) Map<String, Object> mapValue,
                                                    Integer pageNum,
                                                    Integer pageSize,
                                                    Integer apiId,
                                                    Integer dayPlanId) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return amsFeign.getRailOffsetDayplanId(mapValue, pageNum, pageSize, apiId,dayPlanId);
    }

    @ApiModelProperty(value = "下发钢材发往异地库计划")
    @PostMapping("/issueRailOffsetDayplan")
    public Map<String,Object> issueRailOffsetDayplan(@RequestBody List<Map<String,Object>> mapList) {
        return amsFeign.issueRailOffsetDayplan(mapList);
    }

    ////************************************内转物流***************************************************
    /**
     *新增运输计划
     */
    @PostMapping("/addTruckPlan")
    public Map<String,Object> addTruckPlan(@RequestBody  Map<String, Object> mapVal) {
        return amsFeign.addTruckPlan(mapVal);
    }
    //新增采购内转需求
    @PostMapping("/addPurInwardRequirement")
    public Map<String,Object>addPurInwardRequirement(@RequestBody Map<String,Object>mapval){
        return amsFeign.addPurInwardRequirement(mapval);
    }
    //删除
    @PostMapping("/deleteTruckPlan/{planId}")
    public Map<String,Object> deleteTruckPlan(@PathVariable("planId") Integer planId) {
        return amsFeign.deleteTruckPlan(new BigDecimal(planId));
    }

    //接收
    @PostMapping("/receiveInwardPlan/{planId}")
    public Map<String,Object> receiveInwardPlan(@PathVariable("planId") Integer planId) {
        return amsFeign.receiveInwardPlan(new BigDecimal(planId));
    }

    /**
     * 修改渲染
     * @param planId
     * @return
     */
    @PostMapping("/selectInwardPlanToUpdate/{planId}")
    public Map<String,Object> selectInwardPlanToUpdate(@PathVariable("planId") Integer planId) {
        return amsFeign.selectInwardPlanToUpdate(new BigDecimal(planId));
    }

    /**
     * 下发
     * @param mapList
     * @return
     */
    @PostMapping("/downTruckPlan")
    public Map<String,Object> downTruckPlan(@RequestBody List<Map<String,Object>> mapList) {
        return amsFeign.downTruckPlan(mapList);
    }
    /**
     * 修改运输计划/下发运输计划/承运商接收运输计划
     */
    @PostMapping("/updateTruckPlan")
    public Map<String,Object> updateTruckPlan(@RequestBody  Map<String, Object> mapVal){
        return amsFeign.updateTruckPlan(mapVal);
    }
    /**
     * 展示运输计划
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @ApiModelProperty(value = "展示运输计划")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "查询页数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "每页记录数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "apiId", value = "0:257/1,2:258", required = false, dataType = "BigDecimal")
    })
    @PostMapping("/getTruckPlanList")
    public Map<String, Object> getTruckPlanList(@RequestBody(required = false) Map<String,Object> mapValue,
                                                Integer pageNum,
                                                Integer pageSize,
                                                Integer apiId,
                                                Integer planStatus,
                                                String carrierId,
                                                Integer planId) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return amsFeign.getTruckPlanList(mapValue, pageNum, pageSize, apiId,planStatus,carrierId,planId);
    }

    @ApiModelProperty(value = "展示运输计划")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "查询页数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "每页记录数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "apiId", value = "0:257/1,2:258", required = false, dataType = "BigDecimal")
    })
    @PostMapping("/getPlanOrder")
    public Map<String, Object> getPlanOrder(@RequestBody(required = false) Map<String,Object> mapValue,
                                            Integer pageNum,
                                            Integer pageSize,
                                            Integer apiId,
                                            Integer planId,
                                            Integer requirementId,
                                            Integer orderStatus) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return amsFeign.getPlanOrder(mapValue, pageNum, pageSize, apiId,planId,requirementId,orderStatus);
    }
    /**
     *用车单位提出需求
     *新增用车需求
     */
    @PostMapping("/addTruckRequirement")
    public Map<String,Object> addTruckRequirement(@RequestBody  Map<String, Object> mapVal) {
        return amsFeign.addTruckRequirement(mapVal);
    }
    //删除用车需求
    @PostMapping("/deleteTruckRequirement/{requirementId}")
    public Map<String,Object> deleteTruckReqgetTruckRequirementListuirement(@PathVariable("requirementId") BigDecimal requirementId) {
        return amsFeign.deleteTruckRequirement(requirementId);
    }
    //下发用车需求
    @PostMapping("/downRequirement")
    public Map<String,Object> downRequirement(@RequestBody List<Map<String,Object>> requirementIds) {
        return amsFeign.downRequirement(requirementIds);
    }

    //接收用车需求
    @PostMapping("/receiveRequirement/{requirementId}")
    public Map<String,Object> receiveRequirement(@PathVariable("requirementId") Integer requirementId) {
        return amsFeign.receiveRequirement(requirementId);
    }
    /**
     * 修改用车需求
     */
    @PostMapping("/updateTruckRequirement")
    public Map<String,Object> updateTruckRequirement(@RequestBody  Map<String, Object> mapVal){
        return amsFeign.updateTruckRequirement(mapVal);
    }
    /**
     * 查询修改渲染
     */
    @PostMapping("/selectRequirement/{requirementId}")
    public Map<String,Object> selectRequirement(@PathVariable("requirementId") Integer requirementId) {
        return amsFeign.selectRequirement(requirementId);
    }

    /*
    查询需求物资详情
     */
    @PostMapping("/getRequirementMaterial/{requirementId}")
    public Map<String,Object> getRequirementMaterial(@PathVariable("requirementId") Integer requirementId) {
        return amsFeign.getRequirementMaterial(requirementId);
    }
    /**
     * 展示用车需求
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @ApiModelProperty(value = "展示用车需求")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "查询页数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "每页记录数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "apiId", value = "207", required = false, dataType = "BigDecimal")
    })
    @PostMapping("/getTruckRequirementList")
    public Map<String, Object> getTruckRequirementList(@RequestBody(required = false) Map<String,Object> mapValue,
                                          Integer pageNum,
                                          Integer pageSize,
                                          Integer apiId,
                                          Integer requirementStatus,
                                          String orgCode) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return amsFeign.getTruckRequirementList(mapValue, pageNum, pageSize, apiId,requirementStatus,orgCode);
    }

    @PostMapping("/getPurRequirementList")
    public Map<String, Object> getPurRequirementList(@RequestBody(required = false) Map<String,Object> mapValue,
                                                       Integer pageNum,
                                                       Integer pageSize,
                                                       Integer apiId,
                                                       Integer requirementStatus,
                                                       String con,
                                                       String userId,
                                                       String carrierSsoId,
                                                       String enableStatus,
                                                       String planStatus) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return amsFeign.getPurRequirementList(mapValue, pageNum, pageSize, apiId,requirementStatus,con,userId, carrierSsoId,enableStatus,planStatus);
    }
    @ApiOperation(value="查询app端公开抢单")
    @PostMapping("/getDispatchSaleOrderList")
    public Map<String, Object> getDispatchSaleOrderList() {
        return amsFeign.getDispatchSaleOrderList();
    }

    @ApiOperation(value="抢单/接收订单锁定")
    @PostMapping("/lockDispatchSaleOrder")
    public Map<String, Object> lockDispatchSaleOrder(Integer dispatchId,String carrierSsoId) {
        return amsFeign.lockDispatchSaleOrder(dispatchId, carrierSsoId);
    }

    @ApiOperation(value="查询app端承运商已抢到的单")
    @PostMapping("/getLockDispatchSaleOrderList")
    public Map<String, Object> getLockDispatchSaleOrderList(Integer carrierId) {
        return amsFeign.getLockDispatchSaleOrderList(carrierId);
    }

    @ApiOperation(value="查询PC端承运商已抢到的单")
    @PostMapping("/selectDispatchSaleOrderList")
    public Map<String, Object> selectDispatchSaleOrderList(@RequestBody(required=false) Map<String,Object> mapValue,
                                                           Integer apiId,
                                                           Integer pageNum,
                                                           Integer pageSize,
                                                           String carrierSsoId){
        return  amsFeign.selectDispatchSaleOrderList(mapValue==null ?new HashMap<>():mapValue, apiId, pageNum, pageSize,carrierSsoId);
    }

    //获取到站名称
    @GetMapping("/getArriveName")
    public Map<String,Object> getArriveName() {
        return amsFeign.getArriveName();
    }

//    @ApiModelProperty(value = "查询所有的钢材物资")
//    @ApiImplicitParams({
//            @ApiImplicitParam(name = "pageNum", value = "查询页数", required = false, dataType = "Integer"),
//            @ApiImplicitParam(name = "pageSize", value = "每页记录数", required = false, dataType = "Integer"),
//            @ApiImplicitParam(name = "apiId", value = "232", required = false, dataType = "BigDecimal")
//    })
//    @PostMapping("/getAllSteelMaterialMes")
//    public Map<String, Object> getAllSteelMaterialMes(@RequestBody(required = false) Map<String,Object> mapValue,
//                                                Integer pageNum,
//                                                Integer pageSize,
//                                                Integer apiId,
//                                                String con) {
//        return amsFeign.getAllSteelMaterialMes(mapValue==null?new HashMap<>():mapValue, pageNum, pageSize, apiId, con);
//    }

    @ApiModelProperty(value = "查询PC端公开抢单")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "查询页数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "每页记录数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "apiId", value = "242", required = false, dataType = "Integer")
    })
    @PostMapping("/getPCDispatchSaleOrderList")
    public Map<String, Object> getPCDispatchSaleOrderList(@RequestBody(required = false) Map<String,Object> mapValue,
                                                      Integer pageNum,
                                                      Integer pageSize,
                                                      Integer apiId,
                                                      Integer dispatchType,
                                                      @RequestParam String carrierSsoId) {
        return amsFeign.getPCDispatchSaleOrderList(mapValue==null?new HashMap<>():mapValue, pageNum, pageSize, apiId,dispatchType,carrierSsoId);
    }

    @ApiModelProperty(value = "展示批次信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "查询页数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "每页记录数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "apiId", value = "252", required = false, dataType = "Integer")
    })
    @PostMapping("/getPurchaseIdByBatch")
    public Map<String, Object> getPurchaseIdByBatch(@RequestBody(required = false) Map<String,Object> mapValue,
                                                          Integer pageNum,
                                                          Integer pageSize,
                                                          Integer apiId) {
        return amsFeign.getPurchaseIdByBatch(mapValue==null?new HashMap<>():mapValue, pageNum, pageSize, apiId);
    }

    @ApiModelProperty(value = "仓库模代框")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "查询页数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "每页记录数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "apiId", value = "251", required = false, dataType = "Integer")
    })
    @PostMapping("/getWareHouse")
    public Map<String, Object> getWareHouse(@RequestBody(required = false) Map<String,Object> mapValue,
                                                    Integer pageNum,
                                                    Integer pageSize,
                                                    Integer apiId,
                                                    String con) {
        return amsFeign.getWareHouse(mapValue==null?new HashMap<>():mapValue, pageNum, pageSize, apiId, con);
    }

    @ApiModelProperty(value = "车型下拉")
    @GetMapping("/getCapacityType")
    public Map<String,Object> getCapacityType() {
         return amsFeign.getCapacityType();
    }

    @ApiModelProperty(value = "用车单位下拉")
    @GetMapping("/getShipperUser")
    public Map<String,Object> getShipperUser() {
        return amsFeign.getShipperUser();
    }

    @ApiModelProperty(value = "承运商下拉")
    @GetMapping("/getCarrierList")
    public Map<String,Object> getCarrierList() {
        return amsFeign.getCarrierList();
    }

    @ApiModelProperty(value = "到站下拉")
    @GetMapping("/getdayPlanToTheStationId")
    public Map<String,Object> getdayPlanToTheStationId() {
        return amsFeign.getdayPlanToTheStationId();
    }

    @ApiModelProperty(value = "异地库下拉")
    @GetMapping("/getOffsetWarehouse")
    public Map<String,Object> getOffsetWarehouse() {
        return amsFeign.getOffsetWarehouse();
    }

    @PostMapping("/finishTruckPlan/{planId}")
    public Map<String, Object> finishTruckPlan(@PathVariable("planId") Integer planId){
        return amsFeign.finishTruckPlan(planId);
    }


    //零星订单=======================================================================================================================================================

    @ApiModelProperty(value = "查询零星物资订单列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "查询页数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "每页记录数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "apiId", value = "384", required = false, dataType = "Integer")
    })
    @PostMapping("/getSporadicOrdersList")
    public RESTfulResult getSporadicOrdersList(@RequestBody(required = false) Map<String,Object> mapValue,
                                               Integer apiId,
                                               Integer pageNum,
                                               Integer pageSize,
                                               Integer orderType,
                                               Integer issueStatus,
                                               String con,
                                               Integer dispatchStatus,
                                               Integer sporadicStatus,
                                               String carrierSsoId,
                                               String userId,
                                               String userIds) {
        return amsFeign.getSporadicOrdersList(mapValue==null?new HashMap<>():mapValue, apiId, pageNum, pageSize, orderType, issueStatus, con,dispatchStatus,sporadicStatus,carrierSsoId,userId,userIds);
    }

    @ApiModelProperty(value = "查看物资详情")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "查询页数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "每页记录数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "apiId", value = "385", required = false, dataType = "Integer")
    })
    @PostMapping("/seeAllMaterials")
    public RESTfulResult seeAllMaterials(@RequestBody(required = false) Map<String,Object> mapValue,
                                                     Integer apiId,
                                                     Integer pageNum,
                                                     Integer pageSize,
                                                     Integer sporadicOrderId,
                                                     String con){
        return amsFeign.seeAllMaterials(mapValue,apiId,pageNum,pageSize,sporadicOrderId,con);
    }

    @ApiOperation(value="逻辑删除零星物资订单")
    @PostMapping("/deleteSporadicOrders")
    public Map<String, Object> deleteSporadicOrders(@RequestParam Integer sporadicOrderId) {
        return amsFeign.deleteSporadicOrders(sporadicOrderId);
    }




    @ApiOperation(value="下发零星物资订单")
    @PostMapping("/issueSporadicOrders")
    public Map<String, Object> issueSporadicOrders(@RequestBody List<Map<String, Object>> mapList) {
        return amsFeign.issueSporadicOrders(mapList);
    }

    @ApiOperation(value="停止零星订单一车多趟")
    @PostMapping("/closeSporadicOrder")
    public Map<String, Object> closeSporadicOrder(@RequestBody Map<String, Object> map) {
        return amsFeign.closeSporadicOrder(map);
    }


    @ApiOperation(value="内转零星物流添加运输计划")
    @PostMapping("/addInwardSporadicOrder")
    public Map<String, Object> addInwardSporadicOrder(@RequestBody Map<String, Object> map) {
        return amsFeign.addInwardSporadicOrder(map);
    }

    @ApiOperation(value="新增零星物资进出厂（以及销售钢材退货）")
    @PostMapping("/addSporadicOrders")
    public Map<String, Object> addSporadicOrders(@RequestBody Map<String,Object> mapValue) {
        return amsFeign.addSporadicOrders(mapValue);
    }


    @ApiOperation(value="零星一车多趟新增订单")
    @PostMapping("/addSporadicOrderTimes")
    public Map<String, Object> addSporadicOrderTimes(@RequestBody Map<String,Object> mapValue) {
        return amsFeign.addSporadicOrderTimes(mapValue);
    }

    @ApiOperation(value="查询修改渲染")
    @PostMapping("/selectSporadicOrder")
    public RESTfulResult selectSporadicOrder(@RequestParam Integer sporadicOrderId) {
        return amsFeign.selectSporadicOrder(sporadicOrderId);
    }

    @ApiOperation(value="修改零星物资订单")
    @PostMapping("/updateSporadicOrder")
    public Map<String,Object> updateSporadicOrder(@RequestBody Map<String,Object> mapValue) {
        return amsFeign.updateSporadicOrder(mapValue);
    }


    @ApiModelProperty(value = "查询车序号信息")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "查询页数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "每页记录数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "apiId", value = "411", required = false, dataType = "Integer")
    })
    @PostMapping("/getTruckNoList")
    public RESTfulResult getTruckNoList(@RequestBody(required = false) Map<String,Object> mapValue,
                                         Integer apiId,
                                         Integer pageNum,
                                         Integer pageSize,
                                         Integer issueStatus){
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return amsFeign.getTruckNoList(mapValue,apiId,pageNum,pageSize,issueStatus);
    }

    @PostMapping("getSaleOrderInfoes")
    @ApiOperation(value = "查询汽运单价信息")
    public Map<String, Object> getSaleOrderInfoes(@RequestBody(required = false) Map<String, Object> mapValue,
                                                  Integer pageNum,
                                                  Integer pageSize,
                                                  Integer apiId) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return amsFeign.getSaleOrderInfoes(mapValue, pageNum, pageSize, apiId);
    }

    @ApiOperation(value="查询已上报销售订单信息")
    @PostMapping("/getSaleOrderReportedes")
    Map<String, Object> getSaleOrderReportedes(@RequestBody(required = false) Map<String, Object> mapValue,
                                               @RequestParam Integer pageNum,
                                               @RequestParam Integer pageSize,
                                               @RequestParam Integer apiId){
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return amsFeign.getSaleOrderReportedes(mapValue,pageNum,pageSize,apiId);
    }

    @ApiModelProperty(value = "展示销售公司已审核的订单")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "查询页数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "每页记录数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "apiId", value = "409", required = false, dataType = "BigDecimal")
    })
    @PostMapping("/getSaleOrderListBySaleCompanyes")
    public Map<String,Object> getSaleOrderListBySaleCompanyes(@RequestBody(required = false) Map<String,Object> mapValue,
                                                              Integer pageNum,
                                                              Integer pageSize,
                                                              Integer apiId,
                                                              String con,
                                                              Integer shipperId
//                                                              String startDate,
//                                                              String endDate
    ){
        return   amsFeign.getSaleOrderListBySaleCompanyes(mapValue==null?new HashMap<>():mapValue, pageNum, pageSize, apiId, con, shipperId);
    }

    @PostMapping("getAmsSaleOrderApprovedes")
    @ApiOperation(value = "查询财务已审批销售订单信息")
    public Map<String, Object> getAmsSaleOrderApprovedes(@RequestBody(required = false) Map<String, Object> mapValue,
                                                         Integer pageNum,
                                                         Integer pageSize,
                                                         Integer apiId,
                                                         String con) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return amsFeign.getAmsSaleOrderApprovedes(mapValue, pageNum, pageSize, apiId,con);
    }

    /*
     *  根据销售订单主键展示销售基本信息、物资信息
     * apiId=410
     * */
    @PostMapping(value="/getSaleOrderAndMaterialById")
    public RESTfulResult  getSaleOrderAndMaterialById(@RequestBody(required=false) Map<String,Object> mapValue,
                                                      Integer apiId,
                                                      Integer pageNum,
                                                      Integer pageSize,
                                                      Integer saleOrderId){
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return amsFeign.getSaleOrderAndMaterialById(mapValue,apiId,pageNum,pageSize,new BigDecimal(saleOrderId));
    }

    @ApiOperation(value = "新增车序号")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapList", value = "车序号信息", required = false, dataType = ""),
    })
    @PostMapping("/addTruckNo")
    public Map<String, Object> addTruckNo(@RequestBody List<Map<String,Object>> mapList) {
        return amsFeign.addTruckNo(mapList);
    }

    @ApiOperation(value = "下发车序号")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapList", value = "车序号信息", required = false, dataType = ""),
    })
    @PostMapping("/issueTruckNo")
    public Map<String, Object> issueTruckNo(@RequestBody List<Map<String,Object>> mapList) {
        return amsFeign.issueTruckNo(mapList);
    }

    @ApiOperation(value = "展示车序号下的物资详情")
    @PostMapping("/getTruckNoMaterialList")
    public RESTfulResult getTruckNoMaterialList(@RequestParam Integer saleOrderMaterialId) {
        return amsFeign.getTruckNoMaterialList(saleOrderMaterialId);
    }

    @ApiOperation(value = "展示销售订单下的物资详情")
    @PostMapping("/getSaleMaterialList")
    public RESTfulResult getSaleMaterialList(@RequestParam Integer saleOrderId) {
        return amsFeign.getSaleMaterialList(saleOrderId);
    }

    @ApiOperation(value = "展示销售派单物资信息")
    @PostMapping("/getDispatchMaterialList")
    public RESTfulResult getDispatchMaterialList(@RequestParam Integer dispatchId) {
        return amsFeign.getDispatchMaterialList(dispatchId);
    }

    @ApiOperation(value="销售新增定向派单且直接下发")
    @PostMapping("/addDispatchSaleOrder")
    public Map<String,Object> addDispatchSaleOrder(@RequestBody Map<String,Object> mapValue) {
        return amsFeign.addDispatchSaleOrder(mapValue);
    }

   //发布通知================================================================================================================================
    //公告展示


    @ApiOperation(value = "销售公司获取公告信息", notes = "分页查询")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(414)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
    })
    @PostMapping(value = "/getMarketingNoticeList")
    public Map<String, Object> getMarketingNoticeList(@RequestBody(required = false) Map<String, Object> mapValue,
                                                      Integer apiId,
                                                      Integer pageNum,
                                                      Integer pageSize,
                                                      String con
    ) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return amsFeign.getMarketingNoticeList(mapValue == null ? new HashMap<>() : mapValue, apiId, pageNum, pageSize, con);
    }



    @ApiOperation(value = "承运商获取公告信息", notes = "分页查询")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(414)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
    })
    @PostMapping(value = "/getCarrierNoticeList")
    public Map<String, Object> getCarrierNoticeList(@RequestBody(required = false) Map<String, Object> mapValue,
                                                    Integer apiId,
                                                    Integer pageNum,
                                                    Integer pageSize,
                                                    String con
    ) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return amsFeign.getCarrierNoticeList(mapValue == null ? new HashMap<>() : mapValue, apiId, pageNum, pageSize, con);
    }




    @ApiOperation(value = "收货用户获取公告信息", notes = "分页查询")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(414)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
    })
    @PostMapping(value = "/getClientNoticeList")
    public Map<String, Object> getClientNoticeList(@RequestBody(required = false) Map<String, Object> mapValue,
                                                   Integer apiId,
                                                   Integer pageNum,
                                                   Integer pageSize,
                                                   String con
    ) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return amsFeign.getClientNoticeList(mapValue == null ? new HashMap<>() : mapValue, apiId, pageNum, pageSize, con);
    }

    @ApiOperation(value="销售公司直接选择车牌号派发运输订单")
    @PostMapping("/dispatchTruckOrderBySale")
    public Map<String,Object> dispatchTruckOrderBySale(@RequestBody Map<String,Object> mapValue){
        return amsFeign.dispatchTruckOrderBySale(mapValue);
    }

    @ApiOperation(value="展示销售焦炭订单")
    @PostMapping("/getCokeSaleOrderList")
    public RESTfulResult getCokeSaleOrderList(@RequestBody(required = false) Map<String,Object> mapValue,
                                                         Integer pageNum,
                                                         Integer pageSize,
                                                         Integer apiId,
                                                         String con) {
        return amsFeign.getCokeSaleOrderList(mapValue == null ? new HashMap<>() : mapValue, pageNum, pageSize, apiId, con);
    }

    @ApiOperation(value="承运商直接选择车牌号派发运输订单")
    @PostMapping("/dispatchTruckOrderByCarrier")
    public Map<String,Object> dispatchTruckOrderByCarrier(@RequestBody Map<String,Object> mapValue){
        return amsFeign.dispatchTruckOrderByCarrier(mapValue);
    }

    @ApiOperation(value="关闭销售订单")
    @PostMapping("closeSaleOrder")
    public Map<String,Object> closeSaleOrder(@RequestParam Integer saleOrderId){
        return amsFeign.closeSaleOrder(saleOrderId);
    }


    @ApiOperation(value="新增公告信息", notes="根据DilNotice对象创建")
    @ApiImplicitParam(name = "dilNotice", value = "详细实体dilNotice", required = true, dataType = "DilNotice")
    @PostMapping(value = "/insertNotice")
    public Map<String, Object> insertNotice(@RequestBody(required = false) Map<String, Object> map) {
        return amsFeign.insertNotice(map);
    }

    @ApiOperation(value = "更新油价信息", notes = "根据dilNotice对象创建")
    @ApiImplicitParam(name = "dilNotice", value = "详细实体dilNotice", required = true, dataType = "dilNotice")
    @PostMapping(value = "/updateNotice", produces  = "application/json;charset=UTF-8")
    public Map<String, Object> updateNotice(@RequestBody(required = false) Map<String, Object> map) {
        return amsFeign.updateNotice(map);
    }

    @ApiOperation(value="删除", notes="根据url的id来指定删除对象")
    @ApiImplicitParam(paramType = "path", name = "id", value = "ID", required = true, dataType = "BigDecimal")
    @PostMapping(value = "/deleteNotice/{id}")//BigDecimal
    public Map<String, Object> deleteNotice(@PathVariable("id") BigDecimal id) {
        return amsFeign.deleteNotice(id);
    }



    @ApiOperation(value="获取详细信息", notes="根据url的id来获取详细信息")
    @ApiImplicitParam(paramType = "path", name = "公告id", value = "ID", required = true, dataType = "BigDecimal")
    @PostMapping(value = "/getNoticeById/{id}")
    public Map<String, Object> getNoticeById(@PathVariable("id") BigDecimal id){
        return amsFeign.getNoticeById(id);
    }

    @ApiOperation(value="获取最新公告详细信息", notes="根据url的permissions来获取详细信息")
    @ApiImplicitParam(paramType = "name", name = "权限permission", value = "permission", required = true, dataType = "String")
    @PostMapping(value = "/getNewNoticeByPermission/{permissions}")
    public Map<String, Object> getNewNoticeByPermission(@PathVariable("permissions") String permissions){
        return amsFeign.getNewNoticeByPermission(permissions);
    }



    //*******************************下拉框************************


    @GetMapping("getNoticeTypeId")
    @ApiOperation(value = "得到公告类型Id")
    public Map<String,Object> getNoticeTypeId(){
        return amsFeign.getNoticeTypeId();
    }

    @ApiOperation(value="抢单/接收订单锁定")
    @PostMapping("/lockDispatchSaleOrderList")
    public Map<String, Object> lockDispatchSaleOrderList(@RequestBody Map<String,Object> mapValue) {
        return amsFeign.lockDispatchSaleOrderList(mapValue);
    }

    @ApiModelProperty(value = "销售订单批量授权给承运商")
    @PostMapping("/saleOrderEmpowerCarrier")
    public RESTfulResult saleOrderEmpowerCarrier(@RequestBody(required = false) Map<String,Object> mapValue){
        return amsFeign.saleOrderEmpowerCarrier(mapValue);
    }

    @ApiModelProperty(value = "展示销售公司下发给承运商的销售订单列表")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "pageNum", value = "查询页数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "每页记录数", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "apiId", value = "409", required = false, dataType = "BigDecimal")
    })
    @PostMapping("/getSaleOrderListByCarrierSsoId")
    public RESTfulResult getSaleOrderListByCarrierSsoId(@RequestBody(required = false) Map<String,Object> mapValue,
                                                        String carrierSsoId,
                                                        Integer pageNum,
                                                        Integer pageSize,

                                                        Integer apiId,
                                                        String con) {
        return amsFeign.getSaleOrderListByCarrierSsoId(mapValue != null ? mapValue : new HashMap<>(), carrierSsoId, pageNum, pageSize, apiId, con);
    }
    @ApiOperation(value="边输边查具体地址")
    @PostMapping("/getRealAddressByLike")
    public Map<String, Object> getRealAddressByLike(@RequestParam Integer addressId,@RequestParam String index){
        return amsFeign.getRealAddressByLike(addressId,index);
    }

    @ApiOperation(value="得到单价和单价id")
    @PostMapping("/getPriceMap")
    public Map<String, Object> getPriceMap(@RequestBody Map<String,Object> map){
        return amsFeign.getPriceMap(map);
    }

    @ApiOperation(value="得到单价和单价id")
    @PostMapping("/getBenPrice")
    public Map<String, Object> getBenPrice(@RequestBody Map<String,Object> map){
        return amsFeign.getBenPrice(map);
    }

    @ApiOperation(value="批量拒绝定向派单")
    @PostMapping(value = "/refuseDispatchSaleOrderList")
    public Map<String, Object> refuseDispatchSaleOrderList(@RequestBody List<Map<String, Object>> mapList) {
        return amsFeign.refuseDispatchSaleOrderList(mapList);
    }

    @ApiModelProperty(value = "新增钢材销售订单")
    @PostMapping("/addSteelSaleOrder")
    public Map<String, Object> addSteelSaleOrder(@RequestBody Map<String,Object> mapValue) {
        return amsFeign.addSteelSaleOrder(mapValue);
    }

    @ApiModelProperty(value = "查询销售订单下的物资")
    @PostMapping("/getTruckNoAndMaterialList")
    public RESTfulResult getTruckNoAndMaterialList(@RequestParam Integer saleOrderId) {
        return amsFeign.getTruckNoAndMaterialList(saleOrderId);
    }

    @ApiModelProperty(value = "销售钢材派车")
    @PostMapping("/dispatchSteelOrder")
    public Map<String, Object> dispatchSteelOrder(@RequestBody List<Map<String,Object>> mapList) {
        return amsFeign.dispatchSteelOrder(mapList);
    }

    @ApiModelProperty(value = "根据详细地址匹配承运商")
    @GetMapping("/getCarrierByPlace")
    public RESTfulResult getCarrierByPlace(@RequestParam Integer placeId) {
        return amsFeign.getCarrierByPlace(placeId);
    }

    @ApiModelProperty(value = "将车序号下发给承运商")
    @PostMapping("/dispatchToCarrier")
    public RESTfulResult dispatchToCarrier(@RequestBody List<Map<String,Object>> mapList) {
        return amsFeign.dispatchToCarrier(mapList);
    }

    @ApiModelProperty(value = "将车序号下发给承运商")
    @PostMapping("/getSaleOrderListToCarrier")
    public RESTfulResult getSaleOrderListToCarrier(@RequestBody(required = false) Map<String,Object> mapValue,
                                                   @RequestParam Integer pageNum,
                                                   @RequestParam Integer pageSize,
                                                   @RequestParam Integer apiId,
                                                   @RequestParam String carrierSsoId,
                                                   @RequestParam(required = false) String con) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return amsFeign.getSaleOrderListToCarrier(mapValue,pageNum,pageSize,apiId,carrierSsoId,con);
    }

    @ApiModelProperty(value = "展示未匹配承运商的车序号")
    @PostMapping("/getSteelTruckNoList")
    public RESTfulResult getSteelTruckNoList(@RequestBody(required = false) Map<String,Object> mapValue,
                                             @RequestParam Integer apiId,
                                             @RequestParam Integer pageNum,
                                             @RequestParam Integer pageSize,
                                             @RequestParam(required = false) String con) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return amsFeign.getSteelTruckNoList(mapValue,apiId,pageNum,pageSize,con);
    }

    @ApiModelProperty(value = "展示未匹配承运商的车序号详情")
    @PostMapping("/getTruckNoMaterial")
    public RESTfulResult getTruckNoMaterial(@RequestParam Integer saleOrderMaterialId) {
        return amsFeign.getTruckNoMaterial(saleOrderMaterialId);
    }

    @ApiModelProperty(value = "展示已分配承运商但未派车的车序号")
    @PostMapping("/getNoCarTruckNoList")
    public RESTfulResult getNoCarTruckNoList(@RequestBody(required = false) Map<String,Object> mapValue,
                                             @RequestParam Integer apiId,
                                             @RequestParam Integer pageNum,
                                             @RequestParam Integer pageSize,
                                             @RequestParam(required = false) String con) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return amsFeign.getNoCarTruckNoList(mapValue,apiId,pageNum,pageSize,con);
    }

    @ApiModelProperty(value = "展示已派车的车序号")
    @PostMapping("/getHaveCarTruckNoList")
    public RESTfulResult getHaveCarTruckNoList(@RequestBody(required = false) Map<String,Object> mapValue,
                                             @RequestParam Integer apiId,
                                             @RequestParam Integer pageNum,
                                             @RequestParam Integer pageSize,
                                             @RequestParam(required = false) String con) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return amsFeign.getHaveCarTruckNoList(mapValue, apiId, pageNum, pageSize, con);
    }

    @ApiOperation(value="获取零星订单的物资详情")
    @PostMapping(value = "/getSporadic")
    public Map<String, Object> getSporadic(Integer sporadicId) {
        return amsFeign.getSporadic(sporadicId);
    }

    @ApiOperation(value = "查零星订单物资详情")
    @PostMapping("/getSporadicOfOrder")
    public Map<String, Object> getSporadicOfOrder(@RequestBody(required = false) Map<String,Object> mapValue,
                                            Integer apiId,
                                            Integer pageNum,
                                            Integer pageSize,
                                            Integer sporadicId
    ) {
        return amsFeign.getSporadicOfOrder(mapValue==null?new HashMap<>():mapValue, apiId, pageNum, pageSize,sporadicId);
    }


    @ApiOperation(value = "查询内转物流运输单价")
    @PostMapping("/getInwardPriceBy")
    public Map<String,Object>getInwardPriceBy(@RequestBody(required = false)Map<String,Object>mapvalue){
        return amsFeign.getInwardPriceBy(mapvalue);
    }

}
