package com.steerinfo.dil.controller;

import com.steerinfo.dil.feign.WMSHFeign;
import com.steerinfo.dil.util.BaseRESTfulController;
import com.steerinfo.framework.controller.RESTfulResult;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.HashMap;
import java.util.Map;

/**
 * @Description:
 * @Author:HuJianGuo
 * @GreateTime:2021/10/12 9:54
 * @Version:V2.0
 */
@RestController
@RequestMapping("${api.version}/wmsh")
public class WMSHController extends BaseRESTfulController {

    @Autowired
    WMSHFeign wmshFeign;

    /**
     * 展示下游港口港存库库存列表
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping("getUnloadPortStockList")
    @ApiOperation(value = "展示下游港口港存库库存列表")
    public RESTfulResult getUnloadPortStockList(@RequestBody(required = false) Map<String, Object> mapValue,
                                              Integer pageNum,
                                              Integer pageSize,
                                              Integer apiId) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return wmshFeign.getUnloadPortStockList(mapValue, pageNum, pageSize, apiId);
    }

    /**
     * 展示万州港港存库库存列表
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping("getLoadPortStockList")
    @ApiOperation(value = "展示万州港港存库库存列表")
    public RESTfulResult getLoadPortStockList(@RequestBody(required = false) Map<String, Object> mapValue,
                                               Integer pageNum,
                                               Integer pageSize,
                                               Integer apiId) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return wmshFeign.getLoadPortStockList(mapValue, pageNum, pageSize, apiId);
    }

    /**
     * 查询所有港存库入库实绩
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping("getInBoundResult")
    @ApiOperation(value = "查询所有港存库入库实绩")
    public RESTfulResult getInBoundResult(@RequestBody(required = false) Map<String, Object> mapValue,
                                              Integer apiId,
                                              Integer pageNum,
                                              Integer pageSize) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return wmshFeign.getInBoundResult(mapValue, apiId, pageNum, pageSize);
    }

    /**
     * 查询所有港存库出库实绩
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping("getOutBoundResult")
    @ApiOperation(value = "查询所有港存库入库实绩")
    public RESTfulResult getOutBoundResult(@RequestBody(required = false) Map<String, Object> mapValue,
                                          Integer apiId,
                                          Integer pageNum,
                                          Integer pageSize) {
        if (mapValue == null) {
            mapValue = new HashMap<>();
        }
        return wmshFeign.getOutBoundResult(mapValue, apiId, pageNum, pageSize);
    }

    @PostMapping("getResultById/{resultId}")
    @ApiOperation(value = "通过实绩Id查询实绩")
    RESTfulResult getResultById(@PathVariable("resultId") Integer resultId) {
        return wmshFeign.getResultById(resultId);
    }

    @PostMapping("deleteWareHosingResult/{resultId}")
    @ApiOperation(value = "逻辑删除港存库入库实绩")
    RESTfulResult deleteWareHosingResult(@PathVariable("resultId") Integer resultId) {
        return wmshFeign.deleteWareHosingResult(resultId);
    }

    @PostMapping("updateWareHosingResult")
    @ApiOperation(value = "修改港存库入库实绩")
    RESTfulResult updateWareHosingResult(@RequestBody Map<String, Object> wmshInboundResult) {
        return wmshFeign.updateWareHosingResult(wmshInboundResult);
    }

    @PostMapping("addWarehousingResult")
    @ApiOperation(value = "添加港存库入库实绩")
    RESTfulResult addWarehousingResult(@RequestBody Map<String, Object> wmshInboundResult) {
        return wmshFeign.addWarehousingResult(wmshInboundResult);
    }

    @PostMapping("clearWmshGridMaterial")
    @ApiOperation(value = "添加港存库入库实绩")
    RESTfulResult clearWmshGridMaterial(@RequestBody Map<String, Object> wmshInboundResult) {
        return wmshFeign.clearWmshGridMaterial(wmshInboundResult);
    }



    @PostMapping("addResult")
    @ApiOperation(value = "添加港存库出库实绩")
    RESTfulResult addResult(@RequestBody Map<String, Object> map) {
        return wmshFeign.addResult(map);
    }
}
