package com.steerinfo.dil.feign;

import com.steerinfo.framework.controller.RESTfulResult;
import io.swagger.annotations.ApiImplicitParam;
import io.swagger.annotations.ApiImplicitParams;
import io.swagger.annotations.ApiOperation;
import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.http.MediaType;
import org.springframework.util.MultiValueMap;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartRequest;

import java.math.BigDecimal;
import java.util.List;
import java.util.Map;

/**
 * @ author    :TXF
 * @ time      :2021/9/28 9:30
 */

@FeignClient(name = "dil-tms-truck-dev", url = "${openfeign.TmsTruckFeign.url}")
public interface TmsTruckFeign {

    /*
    TmstruckLoadResultController
     */
    @PostMapping("api/v1/truckTms/tmstruckloadresults/addLoadResultForConverted")
    Map<String,Object> addLoadResultForConverted(@RequestBody(required=false) Map<String,Object> map);


    @PostMapping("api/v1/truckTms/tmstruckloadresults/getSaleOrderOnQueue")
    public Map<String, Object> getSaleOrderOnQueue(@RequestBody(required=false) Map<String,Object> mapValue,
                                                   @RequestParam("apiId") Integer apiId,
                                                   @RequestParam("pageNum") Integer pageNum,
                                                   @RequestParam("pageSize") Integer pageSize,
                                                   @RequestParam("con") String con);

    @ApiOperation(value="查询订单下的物资")
    @GetMapping("api/v1/truckTms/dropDown/getOrderMaterial/{orderId}")
    public Map<String, Object> getOrderMaterial(@PathVariable("orderId") Integer orderId);

    @ApiOperation(value="查询仓库下所有月台")
    @GetMapping("api/v1/truckTms/dropDown/getPlatformIdByWarehouse/{warehouseId}")
    public Map<String, Object> getPlatformIdByWarehouse(@PathVariable("warehouseId") Integer warehouseId);

    @ApiOperation(value="修改装车点和装车顺序：销售钢材专用 ")
    @PostMapping("api/v1/truckTms/tmstruckloadresults/updateLoadingIdAndLoadSq")
    public Map<String, Object> updateLoadingIdAndLoadSq(@RequestBody(required=false) Map<String, Object> map);

    @PostMapping("api/v1/truckTms/tmstruckloadresults/getAllLoadResult")
    public Map<String, Object> getAllLoadResult(@RequestBody(required=false) Map<String,Object> mapValue,
                                          @RequestParam("apiId") Integer apiId,
                                          @RequestParam("pageNum") Integer pageNum,
                                          @RequestParam("pageSize") Integer pageSize,
                                          @RequestParam("status") Integer status ,
                                          @RequestParam("orderType") Integer orderType,
                                          @RequestParam("con")   String con,
                                          @RequestParam("userId") String userId,
                                          @RequestParam("userIds") String userIds
    );

    @PostMapping("api/v1/truckTms/tmstruckloadresults/selectLoadResultForConverted")
    public Map<String,Object> selectLoadResultForConverted(@RequestBody(required=false) Map<String,Object> mapValue,
                                          @RequestParam("apiId") Integer apiId,
                                          @RequestParam("pageNum") Integer pageNum,
                                          @RequestParam("pageSize") Integer pageSize);

    @PostMapping("api/v1/truckTms/tmstruckloadresults/getLoadResultByResultId/{resultId}")
    public Map<String,Object> getLoadResultByResultId(@PathVariable("resultId") Integer resultId);

    @PostMapping("api/v1/truckTms/tmstruckloadresults/addUnLoadResultForconverted")
    public Map<String,Object> addUnLoadResultForconverted(@RequestBody(required = false) Map<String,Object> map);

    @PostMapping("api/v1/truckTms/tmstruckloadresults/addCGLoadResult")
    public Map<String, Object> addCGLoadResult(@RequestBody(required=false) Map<String,Object> mapValue);

    @PostMapping("api/v1/truckTms/tmstruckloadresults/addSaleLoadResult")
    public Map<String, Object> addSaleLoadResult(@RequestBody(required=false) Map<String, Object> map);

    @PostMapping("api/v1/truckTms/tmstruckloadresults/addSale2LoadResult")
    public Map<String, Object> addSale2LoadResult(@RequestBody(required=false) Map<String, Object> map);

    @PostMapping("api/v1/truckTms/tmstruckloadresults/updateLoadResult")
    public Map<String, Object> updateLoadResult(@RequestBody(required=false) Map<String,Object> mapValue);

    @PostMapping("api/v1/truckTms/tmstruckloadresults/getLoadResultById/{resultId}")
    public Map<String, Object> getLoadResultById(@PathVariable("resultId") Integer resultId);

    @PostMapping("api/v1/truckTms/tmstruckloadresults/deleteLoadResult/{resultId}")
    public Map<String, Object> deleteLoadResult(@PathVariable("resultId")Integer resultId);
    /*
        TmstruckEnfactoryResultController
     */

    @ApiOperation(value="查询所有的进厂实绩")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "表头和参数", required = false, dataType = "map"),
            @ApiImplicitParam(name = "apiId(99)", value = "动态表头", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageNum", value = "页码", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "pageSize", value = "页", required = false, dataType = "Integer"),
            @ApiImplicitParam(name = "status", value = "状态码", required = false, dataType = "Integer"),
    })
    @PostMapping("api/v1/truckTms/tmstruckenfactoryresults/getAllEnFactoryResult")
    public Map<String, Object> getAllEnFactoryResult(@RequestBody(required=false) Map<String,Object> mapValue,
                                                     @RequestParam("apiId")     Integer apiId,
                                                     @RequestParam("pageNum")   Integer pageNum,
                                                     @RequestParam("pageSize")  Integer pageSize,
                                                     @RequestParam("orderType") Integer orderType,
                                                     @RequestParam("startTime") String startTime,
                                                     @RequestParam("endTime") String endTime,
                                                     @RequestParam("userId")    String userId,
                                                     @RequestParam("userIds")   String userIds
    );
    @GetMapping("api/v1/truckTms/tmstruckenfactoryresults/getMaterial")
    public Map<String , Object> getMaterial(@RequestParam("orderId")  Integer orderId);

    @ApiOperation(value="通过采集系统传来的数据新增进厂作业实绩")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "运输计划实绩对象", required = false, dataType = "Map"),
    })
    @PostMapping("api/v1/truckTms/tmstruckenfactoryresults/addEnFactoryResult")
    public Map<String, Object> addEnFactoryResult(@RequestBody(required=false) Map<String,Object> mapValue);


    @ApiOperation(value="PDA扫描更新进厂作业实绩")
    @ApiImplicitParams({
            @ApiImplicitParam(name = "mapValue", value = "运输计划实绩对象", required = false, dataType = "Map"),
    })
    @PostMapping("api/v1/truckTms/tmstruckenfactoryresults/enFactoryResultByPDA")
    public Map<String, Object> enFactoryResultByPDA(@RequestBody(required=false) Map<String,Object> mapValue);


    /*
        TmstruckWeightResultController
     */

    @PostMapping("api/v1/truckTms/tmstruckweightresults/getAllJiMaoResult")
    public Map<String, Object> getAllJiMaoResult(@RequestBody(required=false) Map<String,Object> mapValue,
                                                 @RequestParam("apiId") Integer apiId,
                                                 @RequestParam("pageNum") Integer pageNum,
                                                 @RequestParam("pageSize") Integer pageSize,
                                                 @RequestParam("orderType") Integer orderType,
                                                 @RequestParam("con")     String con,
                                                 @RequestParam("userId")  String userId,
                                                 @RequestParam("userIds") String userIds
                                                 );

    @PostMapping("api/v1/truckTms/tmstruckweightresults/getAllJiPiResult")
    public Map<String, Object> getAllJiPiResult(@RequestBody(required=false) Map<String,Object> mapValue,
                                                @RequestParam("apiId") Integer apiId,
                                                @RequestParam("pageNum") Integer pageNum,
                                                @RequestParam("pageSize") Integer pageSize,
                                                @RequestParam("orderType") Integer orderType,
                                                @RequestParam("con") String con,
                                                @RequestParam("userId")String userId,
                                                @RequestParam("userIds")String userIds);

    @PostMapping("api/v1/truckTms/tmstruckweightresults/addJiMaoResult")
    public Map<String, Object> addJiMaoResult(@RequestBody Map<String, Object> mapValue);

    @PostMapping("api/v1/truckTms/tmstruckweightresults/addJiPiResult")
    public Map<String, Object> addJiPiResult(@RequestBody Map<String, Object> mapValue);


    /*
     TmstruckUnloadResultController
     */

    @PostMapping("api/v1/truckTms/tmstruckunloadresult/getUnloadResult")
    public Map<String, Object> getUnloadResult(@RequestBody(required=false) Map<String,Object> mapValue,
                                               @RequestParam("apiId") Integer apiId,
                                               @RequestParam("pageNum") Integer pageNum,
                                               @RequestParam("pageSize") Integer pageSize,
                                               @RequestParam("orderType") Integer orderType,
                                               @RequestParam("con")      String con,
                                               @RequestParam("userId") String userId,
                                               @RequestParam("userIds") String userIds
    );

    @PostMapping("api/v1/truckTms/tmstruckunloadresult/addUnloadResult")
    public Map<String, Object> addUnloadResult(@RequestBody Map<String, Object> mapValue);

    @PostMapping("api/v1/truckTms/tmstruckunloadresult/updateUnloadResult")
    public Map<String, Object> updateUnloadResult(@RequestBody Map<String, Object> mapValue);

    /*
    TmstruckReceiptResultController
     */


    @PostMapping("api/v1/truckTms/tmstruckreceiptresults/getReceiveResult")
    public Map<String, Object> getReceiveResult(@RequestBody(required=false) Map<String,Object> mapValue,
                                          @RequestParam("apiId") Integer apiId,
                                          @RequestParam("pageNum") Integer pageNum,
                                          @RequestParam("pageSize") Integer pageSize,
                                          @RequestParam("orderType") Integer orderType,
                                          @RequestParam("con")  String con);

    /*
    TmstruckLeaveFactoryResultController
     */


    @PostMapping("api/v1/truckTms/tmstruckleavefactoryresults/getLeaveFactoryResult")
    public Map<String, Object> getLeaveFactoryResult(@RequestBody(required=false) Map<String,Object> mapValue,
                                               @RequestParam("apiId") Integer apiId,
                                               @RequestParam("pageNum") Integer pageNum,
                                               @RequestParam("pageSize") Integer pageSize,
                                               @RequestParam("orderType") Integer orderType,
                                               @RequestParam("con") String con,
                                               @RequestParam("carrierSsoId")String carrierSsoId,
                                               @RequestParam("userId") String userId,
                                               @RequestParam("userIds") String userIds,
                                               @RequestParam("startTime") String startTime,
                                               @RequestParam("endTime") String endTime
    );

    @PostMapping("api/v1/truckTms/tmstruckleavefactoryresults/addLeaveFactoryResult")
    public Map<String, Object> addLeaveFactoryResult(@RequestBody(required=false) Map<String,Object> mapValue);


    /*
    TmstruckMeasureCommissionController
     */

    @PostMapping("api/v1/truckTms/tmstruckmeasurecommissions/getAllMeasureCommission/{type}")
    public Map<String, Object> getAllMeasureCommission(@PathVariable("type") Integer type);


    /*
    TmstruckQualityResultController
     */
    @PostMapping("api/v1/truckTms/tmstruckqualityresults/getQualityResult")
    public Map<String, Object> getQualityResult(@RequestBody(required=false) Map<String,Object> mapValue,
                                          @RequestParam("apiId") Integer apiId,
                                          @RequestParam("pageNum") Integer pageNum,
                                          @RequestParam("pageSize") Integer pageSize,
                                          @RequestParam("orderType") Integer orderType,
                                          @RequestParam("con")String con);


    @PostMapping("api/v1/truckTms/tmstruckqualityresults/getQualityResultById/{resultId}")
    public Map<String, Object> getQualityResultById(@PathVariable("resultId") Integer resultId);


    @PostMapping("api/v1/truckTms/tmstruckqualityresults/updateQualityResult")
    public Map<String, Object> updateQualityResult(@RequestBody(required=false) Map<String,Object> mapValue);

    //查询质检实绩
    @PostMapping("api/v1/truckTms/tmstruckqualityresults/getQualityResult")
    Map<String,Object> selectQualityResultForConverted(@RequestBody(required=false) Map<String,Object> mapValue,
                                                       @RequestParam("apiId")    Integer apiId,
                                                       @RequestParam("pageNum")  Integer pageNum,
                                                       @RequestParam("pageSize") Integer pageSize);

    /**
     * TmstruckTotalResult
     */
    @PostMapping("api/v1/truckTms/tmstrucktotalresults/selectCountList")
    Map<String,Object> selectCountList(@RequestBody(required=false) Map<String,Object> mapValue,
                                                       @RequestParam("apiId")    Integer apiId,
                                                       @RequestParam("pageNum")  Integer pageNum,
                                                       @RequestParam("pageSize") Integer pageSize);

    /**
     * 下拉框
     */
    @GetMapping("api/v1/truckTms/dropDown/getDilBatch")
    Map<String, Object> getDilBatch();

    @GetMapping("api/v1/truckTms/dropDown/getCarrier")
    Map<String, Object> getCarrier();

    @GetMapping("api/v1/truckTms/dropDown/getLine")
    Map<String, Object> getLine();

    @GetMapping("api/v1/truckTms/dropDown/getWarehouse")
    Map<String, Object> getWarehouse();

    @GetMapping("api/v1/truckTms/dropDown/getGatepost")
    Map<String, Object> getGatepost();

    @GetMapping("api/v1/truckTms/dropDown/getAPO")
    Map<String, Object> getAPO();

    @GetMapping("api/v1/truckTms/dropDown/getFuCapacityId")
    Map<String, Object> getFuCapacityId();

    @GetMapping("api/v1/truckTms/dropDown/getPort")
    Map<String, Object> getPort();

    @GetMapping("api/v1/truckTms/dropDown/getFuMaterial/{type}")
    Map<String, Object> getFuMaterial(@PathVariable("type")Integer type);

    @GetMapping("api/v1/truckTms/dropDown/getUnloadPoint/{type}")
    Map<String, Object> getUnloadPoint(@PathVariable("type") Integer type);
    /**
     * 包月总实绩
     */
    @PostMapping("api/v1/truckTms/tmstrucktotalresults/getTmstruckMonthResult")
    Map<String,Object> getTmstruckMonthResult(@RequestBody(required=false) Map<String,Object> mapValue,
                                       @RequestParam("apiId")    Integer apiId,
                                       @RequestParam("pageNum")  Integer pageNum,
                                       @RequestParam("pageSize") Integer pageSize);
    /**
     *通过运输订单判断下一步是否需要计量,更新汽车衡到计量实绩中
     */
    @PostMapping("api/v1/truckTms/tmstruckweightresults/{orderId}")
    Map<String,Object> isNextNeedJl(@PathVariable("orderId") Integer orderId);


    /**
     *查询短信实绩
     */
    @PostMapping("api/v1/truckTms/tmstrucksmsrusults/getSmsResult")
    Map<String,Object> getSmsResult(@RequestBody(required=false) Map<String,Object> mapValue,
                                    @RequestParam("apiId") Integer apiId,
                                    @RequestParam("pageNum") Integer pageNum,
                                    @RequestParam("pageSize") Integer pageSize,
                                    @RequestParam("con") String con);

    @ApiOperation(value="APP查询进厂实绩")
    @PostMapping("api/v1/truckTms/tmstruckenfactoryresults/getEnfactoryResultList")
    Map<String, Object> getEnfactoryResultList();

    @ApiOperation(value="APP通过运输订单id查询进厂实绩")
    @PostMapping("api/v1/truckTms/tmstruckenfactoryresults/getEnfactoryMessageByOrderId")
    Map<String, Object> getEnfactoryMessageByOrderId(@RequestParam String orderNumber);

    @PostMapping("api/v1/truckTms/tmstrucktimetaskresults/getAllTimeTaskResult")
    public RESTfulResult getAllTimeTaskResult(@RequestBody(required=false) Map<String,Object> mapValue,
                                              @RequestParam("apiId") Integer apiId,
                                              @RequestParam("pageNum") Integer pageNum,
                                              @RequestParam("pageSize") Integer pageSize,
                                              @RequestParam("con") String con,
                                              @RequestParam("userId") String userId,
                                              @RequestParam("startTime") String startTime,
                                              @RequestParam("endTime") String endTime);

    @PostMapping("api/v1/truckTms/tmstruckloadresults/addDaZhouToDaGangLoadResult")
    Map<String, Object> addDaZhouToDaGangLoadResult(@RequestBody(required = false)Map<String, Object> map);

    @ApiOperation(value="新增钢材到异地库达州站驻港人员确定收货")
    @PostMapping("api/v1/truckTms/tmstruckreceiptresults/addSteelNzReceiptResult")
    public Map<String, Object> addSteelNzReceiptResult(@RequestBody(required = false) Map<String, Object> map);


    @PostMapping("api/v1/truckTms/tmstruckweightresults/updateTruckWeight")
    public Map<String, Object> updateTruckWeight(@RequestBody List<Map<String, Object>> mapList);

    @PostMapping("api/v1/truckTms/tmstruckreturnresults/getAllReturnResult")
    public Map<String, Object>  getAllReturnResult(@RequestBody(required=false) Map<String,Object> mapValue,
                                                   @RequestParam("apiId") Integer apiId,
                                                   @RequestParam("pageNum") Integer pageNum,
                                                   @RequestParam("pageSize") Integer pageSize,
                                                   @RequestParam("orderType") Integer orderType,
                                                   @RequestParam("con") String con);

    @PostMapping("api/v1/truckTms/selfMachine/getBillOrder")
    Map<String, Object> getBillOrder(@RequestParam String orderNumber);

    @PostMapping("api/v1/truckTms/selfMachine/getDeliveryOrder")
    Map<String, Object> getDeliveryOrder(@RequestParam String orderNumber);

    @PostMapping("api/v1/truckTms/statisticalReport/getRLFLReport")
    Map<String, Object> getRLFLReport(@RequestBody(required=false) Map<String,Object> mapValue,
                                      @RequestParam("apiId") Integer apiId,
                                      @RequestParam("pageNum") Integer pageNum,
                                      @RequestParam("pageSize") Integer pageSize,
                                      @RequestParam("startTime") String startTime,
                                      @RequestParam("endTime")   String endTime,
                                      @RequestParam("orderType") Integer orderType
    );

    @PostMapping("api/v1/truckTms/tmstruckloadresults/cgNzLoadingResult")
    Map<String, Object> cgNzLoadingResult(@RequestBody(required = false) Map<String, Object> mapval,
                                          @RequestParam Integer apiId,
                                          @RequestParam Integer pageNum,
                                          @RequestParam Integer pageSize,
                                          @RequestParam Integer orderType,
                                          @RequestParam Integer orderStatus);

    @PostMapping("api/v1/truckTms/statisticalReport/getAllSaleReport")
    Map<String, Object> getAllSaleReport(@RequestBody(required=false) Map<String,Object> mapValue,
                                      @RequestParam("apiId") Integer apiId,
                                      @RequestParam("pageNum") Integer pageNum,
                                      @RequestParam("pageSize") Integer pageSize,
                                         @RequestParam("startTime") String startTime,
                                         @RequestParam("endTime")   String endTime,
                                      @RequestParam("carrierSsoId")   String carrierSsoId
    );

    @PostMapping("api/v1/truckTms/statisticalReport/getAllSaleReportTotal")
    Map<String, Object> getAllSaleReportTotal(@RequestBody(required=false) Map<String,Object> mapValue,
                                         @RequestParam("startTime") String startTime,
                                         @RequestParam("endTime")   String endTime,
                                         @RequestParam("carrierSsoId")   String carrierSsoId
    );

    @PostMapping("api/v1/truckTms/statisticalReport/getSporadicSuppliesReport1")
    Map<String, Object> getSporadicSuppliesReport1(@RequestBody(required=false) Map<String,Object> mapValue,
                                                   @RequestParam("apiId") Integer apiId,
                                                   @RequestParam("pageNum") Integer pageNum,
                                                   @RequestParam("pageSize") Integer pageSize,
                                                   @RequestParam("startTime") String startTime,
                                                   @RequestParam("endTime") String endTime,
                                                   @RequestParam("carrierSsoId") String carrierSsoId,
                                                   @RequestParam("userId") String userId,
                                                   @RequestParam("userIds") String userIds,
                                                   @RequestParam("con") String con,
                                                   @RequestParam("orderType") Integer orderType
    );
    @PostMapping("api/v1/truckTms/statisticalReport/getSporadicSuppliesReport2")
    Map<String, Object> getSporadicSuppliesReport2(@RequestBody(required=false) Map<String,Object> mapValue,
                                                   @RequestParam("apiId") Integer apiId,
                                                   @RequestParam("pageNum") Integer pageNum,
                                                   @RequestParam("pageSize") Integer pageSize,
                                                   @RequestParam("startTime") String startTime,
                                                   @RequestParam("endTime") String endTime,
                                                   @RequestParam("carrierSsoId") String carrierSsoId,
                                                   @RequestParam("userId") String userId,
                                                   @RequestParam("userIds") String userIds,
                                                   @RequestParam("con") String con,
                                                   @RequestParam("orderType") Integer orderType
    );
    //内转统计报表
    @PostMapping("api/v1/truckTms/statisticalReport/getAllInwardResult")
    Map<String, Object> getAllInwardResult(@RequestBody(required=false) Map<String,Object> mapValue,
                                         @RequestParam("apiId") Integer apiId,
                                         @RequestParam("pageNum") Integer pageNum,
                                         @RequestParam("pageSize") Integer pageSize,
                                         @RequestParam("startTime") String startTime,
                                         @RequestParam("endTime")   String endTime,
                                         @RequestParam("carrierSsoId")   String carrierSsoId
    );

    //采购内转统计报表
    @PostMapping("api/v1/truckTms/statisticalReport/getPurInwardReport")
    Map<String, Object> getPurInwardReport(@RequestBody(required = false) Map<String, Object> mapValue,
                                           @RequestParam Integer apiId,
                                           @RequestParam Integer pageNum,
                                           @RequestParam Integer pageSize,
                                           @RequestParam String startTime,
                                           @RequestParam String endTime);
//内转统计报表
    @PostMapping("api/v1/truckTms/statisticalReport/getInwardReport")
    Map<String, Object> getInwardReport(@RequestBody(required = false) Map<String, Object> mapValue,
                                           @RequestParam Integer apiId,
                                           @RequestParam Integer pageNum,
                                           @RequestParam Integer pageSize,
                                           @RequestParam String startTime,
                                           @RequestParam String endTime);

    @PostMapping("api/v1/truckTms/tmstruckmeasurecommissions/sendMeasureCommission")
    Map<String, Object> sendMeasureCommission(@RequestBody(required = false) Map<String, Object> map);


    //发送留皮计量委托
    @GetMapping("api/v1/truckTms/tmstruckmeasurecommissions/sendLiuPiMeasureCommission")
    Map<String, Object> sendLiuPiMeasureCommission(@RequestParam("capacityNumber")String capacityNumber);


    //新增计时作业实绩
    @PostMapping("api/v1/truckTms/tmstrucktimetaskresults/addTimeTaskResult")
    Map<String, Object> addTimeTaskResult(@RequestBody(required = false) Map<String, Object> map);


    @PostMapping("api/v1/truckTms/statisticalReport/getLoading")
    Map<String, Object> getLoading(@RequestBody(required = false) Map<String, Object> mapValue,
                                   @RequestParam Integer apiId,
                                   @RequestParam Integer pageNum,
                                   @RequestParam Integer pageSize,
                                   @RequestParam String startTime,
                                   @RequestParam String endTime);

    @PostMapping("api/v1/truckTms/statisticalReport/getUnLoading")
    Map<String, Object> getUnLoading(@RequestBody(required = false) Map<String, Object> mapValue,
                                     @RequestParam Integer apiId,
                                     @RequestParam Integer pageNum,
                                     @RequestParam Integer pageSize,
                                     @RequestParam String startTime,
                                     @RequestParam String endTime);


    @PostMapping("api/v1/truckTms/statisticalReport/getLoaderResult")
    Map<String, Object> getLoaderResult(@RequestBody(required = false) Map<String, Object> mapValue,
                                     @RequestParam Integer apiId,
                                     @RequestParam Integer pageNum,
                                     @RequestParam Integer pageSize,
                                     @RequestParam String startTime,
                                     @RequestParam String endTime);


    @PostMapping("api/v1/truckTms/tmstrucktimetaskresults/JudgeTimeTask")
    Map<String, Object> JudgeTimeTask(@RequestBody Map<String, Object> map);

    @PostMapping("api/v1/truckTms/tmstrucktimetaskresults/unitSureEndTimeout")
    Map<String, Object> unitSureEndTimeout(@RequestBody Map<String, Object> map);

    @PostMapping("api/v1/truckTms/tmstrucktimetaskresults/JudgeTimeTaskPause")
    Map<String, Object> JudgeTimeTaskPause(@RequestBody Map<String, Object> map);

    @PostMapping("api/v1/truckTms/statisticalReport/getLXInwardReport")
    Map<String, Object> getLXInwardReport(@RequestBody(required = false) Map<String, Object> mapValue,
                                     @RequestParam Integer apiId,
                                     @RequestParam Integer pageNum,
                                     @RequestParam Integer pageSize,
                                     @RequestParam String startTime,
                                     @RequestParam String endTime);


    @PostMapping("api/v1/truckTms/statisticalReport/getCapacityByDefend")
    Map<String, Object> getCapacityByDefend(@RequestBody(required = false) Map<String, Object> mapValue,
                                          @RequestParam Integer apiId,
                                          @RequestParam Integer pageNum,
                                          @RequestParam Integer pageSize,
                                          @RequestParam String con
                                         );

    @PostMapping("api/v1/truckTms/tmstruckreceiptresults/getReceiptResult")
    Map<String, Object> getReceiptResult(@RequestBody(required = false) Map<String, Object> mapValue,
                                            @RequestParam Integer apiId,
                                            @RequestParam Integer pageNum,
                                            @RequestParam Integer pageSize,
                                            @RequestParam String con,
                                            @RequestParam String startTime,
                                            @RequestParam String endTime
    );

    @PostMapping("api/v1/truckTms/tmstruckreceiptresults/getReceiptPhoto")
    String getReceiptPhoto(@RequestParam String orderNumber);

    @PostMapping("api/v1/truckTms/tmstruckreceiptresults/getReceivingResult")
    Map<String, Object> getReceivingResult(@RequestBody(required = false) Map<String, Object> mapValue,
                                         @RequestParam Integer apiId,
                                         @RequestParam Integer pageNum,
                                         @RequestParam Integer pageSize,
                                         @RequestParam String con,
                                         @RequestParam String startTime,
                                         @RequestParam String endTime
    );

    @PostMapping("api/v1/truckTms/tmstruckreceiptresults/getReceivingPhoto")
    Map<String,Object> getReceivingPhoto(@RequestParam String orderNumber);

    @PostMapping("/api/v1/truckTms/pathDisplay/fullPath")
    public Object fullPath(@RequestParam("orderNumber") String orderNumber) throws Exception;
    @PostMapping("/api/v1/truckTms/pathDisplay/getInTransitTransportation")
    public RESTfulResult getInTransitTransportation(@RequestBody Map<String,Object> mapValue,
                                                    @RequestParam(required = true,defaultValue = "468",name = "apiId")Integer apiId,
                                                    @RequestParam(required = false,name = "pageNum")Integer pageNum,
                                                    @RequestParam(required = false,name = "pageSize")Integer pageSize);
    @PostMapping(value = "/api/v1/truckTms/tmstruckarrivalresults/addtmstruckArrivalResult",consumes = MediaType.MULTIPART_FORM_DATA_VALUE)
    public RESTfulResult addtmstruckArrivalResult(@RequestParam("orderNumber")String orderNumber, @RequestParam("resultArrivalAddress")String resultArrivalAddress,@RequestPart("file") MultipartFile file);

    @PostMapping(value = "/api/v1/truckTms/pathDisplay/addTmstruckReceiptResult")
    public  RESTfulResult addTmstruckReceiptResult(@RequestBody Map<String,Object>  mapValaue  , @RequestParam("num") Integer num, @RequestParam("orderNumber")  String orderNumber, @RequestParam("resultArrivalAddress")String resultArrivalAddress, @RequestParam("imgcount3") Integer imgcount3, @RequestParam("imgcount4")Integer imgcount4);

    @PostMapping(value = "/api/v1/truckTms/tmstruckarrivalresults/uploadImage",consumes = MediaType.MULTIPART_FORM_DATA_VALUE)
    public String uploadImage(@RequestParam("orderNumber")String orderNumber,@RequestPart("file") MultipartFile file);

//    @PostMapping(value = "/api/v1/truckTms/pathDisplay/addTmstruckReceiptResult", headers = "content-type=multipart/form-data",consumes = MediaType.MULTIPART_FORM_DATA_VALUE)
//    public  RESTfulResult addTmstruckReceiptResult(@RequestPart("file")MultipartRequest request,@RequestParam("num") Integer num,@RequestParam("orderNumber")  String orderNumber, @RequestParam("resultArrivalAddress")String resultArrivalAddress,@RequestParam("imgcount3") Integer imgcount3, @RequestParam("imgcount4")Integer imgcount4);
    @PostMapping("/api/v1/truckTms/pathDisplay/getFinishTruckOrderInfo")
    public RESTfulResult getFinishTruckOrderInfo(@RequestBody Map<String,Object> mapValue,
                                                 @RequestParam(required = true,defaultValue = "468",name = "apiId")Integer apiId,
                                                 @RequestParam(required = false,defaultValue = "1",name = "pageNum")Integer pageNum,
                                                 @RequestParam(required = false,defaultValue = "20",name = "pageSize")Integer pageSize
    );

}






