package com.steerinfo.dil.feign;

import org.springframework.cloud.openfeign.FeignClient;
import org.springframework.web.bind.annotation.*;

import java.math.BigDecimal;
import java.util.Map;

/**
 * @Description:
 * @Author:HuJianGuo
 * @GreateTime:2021/9/23 8:46
 * @Version:V2.0
 */
@FeignClient(value = "DIL-SHIPTMS-API-DEV", url = "${openfeign.TmsshipFeign.url}")
public interface TmsshipFeign {

    /**
     * 展示驳船
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/tmsshipbargeoperations/getBargeOperationList")
    Map<String, Object> getBargeOperationList(@RequestBody(required = false) Map<String, Object> mapValue,
                                        @RequestParam Integer pageNum,
                                        @RequestParam Integer pageSize,
                                        @RequestParam Integer apiId);

    /**
     * 查询驳船作业信息
     *
     * @param bargeOperationId
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/tmsshipbargeoperations/getBargeOperation/{bargeOperationId}")
    Map<String, Object> getBargeOperation(@PathVariable("bargeOperationId") BigDecimal bargeOperationId);

    /**
     * 查询驳船作业信息
     *
     * @param bargeOperationId
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/tmsshipbargeoperations/selectBargeOperation/{bargeOperationId}")
    Map<String, Object> selectBargeOperation(@PathVariable("bargeOperationId") BigDecimal bargeOperationId);

    /**
     * 删除驳船作业信息
     *
     * @param bargeOperationId
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/tmsshipbargeoperations/deleteBargeOperation/{bargeOperationId}")
    Map<String, Object> deleteBargeOperation(@PathVariable("bargeOperationId") BigDecimal bargeOperationId);

    /**
     * 修改驳船作业信息
     *
     * @param tmsshipBargeOperation
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/tmsshipbargeoperations/updateBargeOperation")
    Map<String, Object> updateBargeOperation(@RequestBody Map<String, Object> tmsshipBargeOperation);

    /**
     * 新增驳船作业
     *
     * @param map
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/tmsshipbargeoperations/addBargeOperation")
    Map<String, Object> addBargeOperation(@RequestBody Map<String, Object> map);

    /**
     * 新增抵达实绩
     *
     * @param mapVal
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/tmsshipentrywharyresults/addTmsShipEntryWharyResult")
    Map<String, Object> addTmsShipEntryWharyResult(@RequestBody Map<String, Object> mapVal);

    /**
     * 新增离港实绩
     *
     * @param mapVal
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/tmsshipoutwharyresults/addTmsShipOutWharyResult")
    Map<String, Object> addTmsShipOutWharyResult(@RequestBody Map<String, Object> mapVal);

    /**
     * 展示装船作业信息列表
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/tmsshiploadshipresults/getLoadShipList")
    Map<String, Object> getLoadShipList(@RequestBody(required = false) Map<String, Object> mapValue,
                                  @RequestParam Integer pageNum,
                                  @RequestParam Integer pageSize,
                                  @RequestParam Integer apiId);

    /**
     * 查询装船作业表单
     *
     * @param resultId
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/tmsshiploadshipresults/getLoadShip/{resultId}")
    Map<String, Object> getLoadShip(@PathVariable("resultId") BigDecimal resultId);

    /**
     * 查询装船作业信息
     *
     * @param resultId
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/tmsshiploadshipresults/selectLoadShip/{resultId}")
    Map<String, Object> selectLoadShip(@PathVariable("resultId") BigDecimal resultId);

    /**
     * 删除装船作业信息
     *
     * @param resultId
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/tmsshiploadshipresults/deleteLoadShip/{resultId}")
    Map<String, Object> deleteLoadShip(@PathVariable("resultId") BigDecimal resultId);

    /**
     * 修改装船作业信息
     *
     * @param tmsshipLoadShipResult
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/tmsshiploadshipresults/updateLoadShip")
    Map<String, Object> updateLoadShip(@RequestBody Map<String, Object> tmsshipLoadShipResult);

    /**
     * 新增装船作业
     *
     * @param map
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/tmsshiploadshipresults/addLoadShip")
    Map<String, Object> addLoadShip(@RequestBody Map<String, Object> map);

    /**
     * 展示位置作业信息列表
     *
     * @param mapValue
<<<<<<< HEAD
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/tmsshipshiplocations/getShipLocationList")
    Map<String, Object> getShipLocationList(@RequestBody(required = false) Map<String, Object> mapValue,
                                      @RequestParam Integer pageNum,
                                      @RequestParam Integer pageSize,
                                      @RequestParam Integer apiId,
                                            @RequestParam String con);

    @PostMapping(value = "/api/v1/shipTms/tmsshipshiplocations/getShipLocationList")
    Map<String, Object> getShipLocationList(@RequestBody(required = false) Map<String, Object> mapValue);


    /**
     * 查询位置作业信息
     *
     * @param locationId
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/tmsshipshiplocations/getShipLocation/{locationId}")
    Map<String, Object> getShipLocation(@PathVariable("locationId") BigDecimal locationId);

    /**
     * 查询位置作业信息
     *
     * @param locationId
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/tmsshipshiplocations/selectShipLocation/{locationId}")
    Map<String, Object> selectShipLocation(@PathVariable("locationId") BigDecimal locationId);

    /**
     * 删除位置作业信息
     *
     * @param locationId
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/tmsshipshiplocations/deleteShipLocation/{locationId}")
    Map<String, Object> deleteShipLocation(@PathVariable("locationId") BigDecimal locationId);

    /**
     * 修改位置作业信息
     *
     * @param tmsshipShipLocation
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/tmsshipshiplocations/updateShipLocation")
    Map<String, Object> updateShipLocation(@RequestBody Map<String, Object> tmsshipShipLocation);

    /**
     * 新增位置作业
     *
     * @param map
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/tmsshipshiplocations/addShipLocation")
    Map<String, Object> addShipLocation(@RequestBody Map<String, Object> map);

    /**
     * 展示水路货物运单列表
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/tmsshiptotalresults/listAllOrders")
    Map<String, Object> listAllOrders(@RequestBody(required = false) Map<String, Object> mapValue,
                                @RequestParam Integer pageNum,
                                @RequestParam Integer pageSize,
                                @RequestParam Integer apiId);

    /**
     * 展示船只信息
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/tmsshiptotalresults/getCapacityList")
    Map<String, Object> getCapacityList(@RequestBody(required = false) Map<String, Object> mapValue,
                                        @RequestParam Integer pageNum,
                                        @RequestParam Integer pageSize,
                                        @RequestParam Integer apiId);

    /**
     * 展示卸船作业信息列表
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/tmsshipunloadshipresults/getUnLoadShipList")
    Map<String, Object> getUnLoadShipList(@RequestBody(required = false) Map<String, Object> mapValue,
                                          @RequestParam Integer pageNum,
                                          @RequestParam Integer pageSize,
                                          @RequestParam Integer apiId);

    /**
     * 查询卸船作业信息
     *
     * @param resultId
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/tmsshipunloadshipresults/getUnloadShip/{resultId}")
    Map<String, Object> getUnloadShip(@PathVariable("resultId") BigDecimal resultId);

    /**
     * 查询卸船作业信息
     *
     * @param resultId
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/tmsshipunloadshipresults/selectUnLoadShip/{resultId}")
    Map<String, Object> selectUnLoadShip(@PathVariable("resultId") BigDecimal resultId);

    /**
     * 删除卸船作业信息
     *
     * @param resultId
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/tmsshipunloadshipresults/deleteUnLoadShip/{resultId}")
    Map<String, Object> deleteUnLoadShip(@PathVariable("resultId") BigDecimal resultId);

    /**
     * 修改卸船作业信息
     *
     * @param tmsshipUnloadShipResult
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/tmsshipunloadshipresults/updateUnLoadShip")
    Map<String, Object> updateUnLoadShip(@RequestBody Map<String, Object> tmsshipUnloadShipResult);

    /**
     * 新增卸船作业
     *
     * @param map
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/tmsshipunloadshipresults/addUnLoadShip")
    Map<String, Object> addUnLoadShip(@RequestBody Map<String, Object> map);

    /**
     * 展示水分质检信息列表
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/tmsshipwaterqualityresults/getWaterQualityResultList")
    Map<String, Object> getWaterQualityResultList(@RequestBody(required = false) Map<String, Object> mapValue,
                                            @RequestParam Integer pageNum,
                                            @RequestParam Integer pageSize,
                                            @RequestParam Integer apiId);

    /**
     * 查询水分质检信息
     *
     * @param resultId
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/tmsshipwaterqualityresults/getWaterQuality/{resultId}")
    Map<String, Object> getWaterQuality(@PathVariable("resultId") BigDecimal resultId);

    /**
     * 查询水分质检信息
     *
     * @param resultId
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/tmsshipwaterqualityresults/selectWaterQualityResult/{resultId}")
    Map<String, Object> selectWaterQualityResult(@PathVariable("resultId") BigDecimal resultId);

    /**
     * 删除水分质检信息
     *
     * @param resultId
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/tmsshipwaterqualityresults/deleteWaterQualityResult/{resultId}")
    Map<String, Object> deleteWaterQualityResult(@PathVariable("resultId") BigDecimal resultId);

    /**
     * 修改水分质检作业信息
     *
     * @param tmsshipWaterQualityResult
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/tmsshipwaterqualityresults/updateWaterQualityResult")
    Map<String, Object> updateWaterQualityResult(@RequestBody Map<String, Object> tmsshipWaterQualityResult);

    /**
     * 新增水分质检作业
     *
     * @param map
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/tmsshipwaterqualityresults/addWaterQualityResult")
    Map<String, Object> addWaterQualityResult(@RequestBody Map<String, Object> map);

    /**
     * 展示船只信息列表
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/omsshipinstructionscapacitys/getCapacities")
    Map<String, Object> getCapacities(@RequestParam BigDecimal instructionsId,
                                @RequestBody(required = false) Map<String, Object> mapValue,
                                @RequestParam Integer pageNum,
                                @RequestParam Integer pageSize,
                                @RequestParam Integer apiId);

    /**
     * 新增船只
     *
     * @param omsshipInstructionsCapacity
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/omsshipinstructionscapacitys/addInstructionsCapacity")
    Map<String, Object> addInstructionsCapacity(@RequestBody Map<String, Object> omsshipInstructionsCapacity);

    /**
     * 查询船只
     *
     * @param instructionsCapacityId
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/omsshipinstructionscapacitys/getInstructionsCapacity/{instructionsCapacityId}")
    Map<String, Object> getInstructionsCapacity(@PathVariable("instructionsCapacityId") BigDecimal instructionsCapacityId);

    /**
     * 逻辑删除船只
     *
     * @param instructionsCapacityId
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/omsshipinstructionscapacitys/deleteInstructionsCapacity/{instructionsCapacityId}")
    Map<String, Object> deleteInstructionsCapacity(@PathVariable("instructionsCapacityId") BigDecimal instructionsCapacityId);

    /**
     * 修改船只信息
     *
     * @param omsshipInstructionsCapacity
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/omsshipinstructionscapacitys/updateInstructionsCapacity")
    Map<String, Object> updateInstructionsCapacity(@RequestBody Map<String, Object> omsshipInstructionsCapacity);

    /**
     * 展示装船指令
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/omsshipshipmentinstructions/getShipMentInstructionsList")
    Map<String, Object> getShipMentInstructionsList(@RequestBody(required = false) Map<String, Object> mapValue,
                                              @RequestParam Integer pageNum,
                                              @RequestParam Integer pageSize,
                                              @RequestParam Integer apiId,
                                                    @RequestParam String status);

    /**
     * 查询装船指令
     *
     * @param instructionsId
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/omsshipshipmentinstructions/getShipmentInstructions/{instructionsId}")
    Map<String, Object> getShipmentInstructions(@PathVariable("instructionsId") BigDecimal instructionsId);

    /**
     * 查询装船指令
     *
     * @param shipmentInstructionsId
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/omsshipshipmentinstructions/sendShipmentInstructionsStatus/{shipmentInstructionsId}")
    Map<String, Object> sendShipmentInstructionsStatus(@PathVariable("shipmentInstructionsId") BigDecimal shipmentInstructionsId);

    /**
     * 删除装船指令
     *
     * @param instructionsId
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/omsshipshipmentinstructions/deleteByPrimaryKey/{instructionsId}")
    Map<String, Object> deleteByPrimaryKey(@PathVariable("instructionsId") BigDecimal instructionsId);

    /**
     * 修改装船指令
     *
     * @param omsshipShipmentInstructions
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/omsshipshipmentinstructions/updateShipmentInstructions")
    Map<String, Object> updateShipmentInstructions(@RequestBody Map<String, Object> omsshipShipmentInstructions);

    /**
     * 新增装船指令
     *
     * @param omsshipShipmentInstructions
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/omsshipshipmentinstructions/addShipmentInstructions")
    Map<String, Object> addShipmentInstructions(@RequestBody Map<String, Object> omsshipShipmentInstructions);

    /**
     * 下拉框
     * @return
     */
    @GetMapping(value = "/api/v1/shipTms/amsshipcargotransferresults/getGroupId")
    Map<String, Object> getGroupId();

    @GetMapping(value = "/api/v1/shipTms/amsshipcargotransferresults/getCargoId")
    Map<String, Object> getCargoId();

    @GetMapping(value = "/api/v1/shipTms/amsshipcargotransferresults/insertBetchId")
    Map<String, Object> insertBetchId();

    @GetMapping(value = "/api/v1/shipTms/amsshipdeliveryattorneys/getAttorneyId")
    Map<String, Object> getAttorneyId();

    @GetMapping(value = "/api/v1/shipTms/amsshipdeliveryattorneys/getNoticeId")
    Map<String, Object> getNoticeId();

    @GetMapping(value = "/api/v1/shipTms/amsshipdeliveryattorneys/getPortName")
    Map<String, Object> getPortName();

    @GetMapping(value = "/api/v1/shipTms/amsshipdeliveryattorneys/getPortId")
    Map<String, Object> getPortId();

    @GetMapping(value = "/api/v1/shipTms/amsshipdeliveryattorneys/getRmRawId")
    Map<String, Object> getRmRawId();

    @GetMapping(value = "/api/v1/shipTms/amsshipdeliveryattorneys/getPierId")
    Map<String, Object> getPierId();

    @GetMapping(value = "/api/v1/shipTms/amsshipdeliverynotices/getResultNumber")
    Map<String, Object> getResultNumber();

    @GetMapping(value = "/api/v1/shipTms/amsshipdeliverynotices/getCarrier")
    Map<String, Object> getCarrier();

    @GetMapping(value = "/api/v1/shipTms/amsshipdeliverynotices/getShipper")
    Map<String, Object> getShipper();

    @GetMapping(value = "/api/v1/shipTms/omsshipinstructionscapacitys/getOrderId")
    Map<String, Object> getTask();

    @GetMapping(value = "/api/v1/shipTms/omsshipinstructionscapacitys/getCapacityId")
    Map<String, Object> getCapacityId();

    @GetMapping(value = "/api/v1/shipTms/omsshipshipmentinstructions/getBatchId")
    Map<String, Object> getBatchId();


    @PostMapping(value = "/api/v1/shipTms/dilbatchs/getBatchList")
    Map<String, Object> getBatchList(@RequestBody(required = false) Map<String, Object> mapValue,
                                     @RequestParam Integer pageNum,
                                     @RequestParam Integer pageSize,
                                     @RequestParam Integer apiId);



    @PostMapping(value = "/api/v1/shipTms/dilbatchs/getBatchListForAttorney")
    Map<String, Object> getBatchListForAttorney(@RequestBody(required = false) Map<String, Object> mapValue,
                                     @RequestParam Integer pageNum,
                                     @RequestParam Integer pageSize,
                                     @RequestParam Integer apiId,
                                     @RequestParam String con);

    //获取船运物资id
    @GetMapping("/api/v1/shipTms/amsshipcargotransferresults/getMaterialId")
    Map<String,Object> getMaterialId();

    /**
     * 展示货权转移
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/amsshipcargotransferresults/getAmsshipCargoTranferResultList")
    Map<String, Object> getAmsshipCargoTranferResultList(@RequestBody(required = false) Map<String, Object> mapValue,
                                                         @RequestParam Integer pageNum,
                                                         @RequestParam Integer pageSize,
                                                         @RequestParam Integer apiId);
    @PostMapping(value = "/api/v1/shipTms/amsshipcargotransferresults/selectShippeByName")
    Map<String, Object>   selectShippeByName(@RequestBody(required = false) Map<String, Object> mapValue,
                                             @RequestParam Integer pageNum,
                                             @RequestParam Integer pageSize,
                                             @RequestParam Integer apiId,
                                             @RequestParam String con);
    @PostMapping(value = "/api/v1/shipTms/amsshipcargotransferresults/getMaterialList")
       Map<String, Object>  getMaterialList(@RequestBody(required = false) Map<String, Object> mapValue,
                                             @RequestParam Integer pageNum,
                                             @RequestParam Integer pageSize,
                                             @RequestParam Integer apiId,
                                             @RequestParam String con);

    @PostMapping(value = "/api/v1/shipTms/amsshipcargotransferresults/getGroupList")
      Map<String, Object> getGroupList (@RequestBody(required = false) Map<String, Object> mapValue,
                                             @RequestParam Integer pageNum,
                                             @RequestParam Integer pageSize,
                                             @RequestParam Integer apiId,
                                             @RequestParam String con);
    /**
     * 新增货权转移
     *
     * @param amsshipCargoTransferResult
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/amsshipcargotransferresults/insertamsshipCargoTransferResult")
    Map<String, Object> insertamsshipCargoTransferResult(@RequestBody Map<String, Object> amsshipCargoTransferResult);

    /**
     * 逻辑删除货权转移
     *
     * @param cargoTransferResultId
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/amsshipcargotransferresults/deleteByCargoId/{cargoTransferResultId}")
    Map<String, Object> deleteByCargoId(@PathVariable("cargoTransferResultId") Integer cargoTransferResultId);

    /**
     * 修改货权转移
     *
     * @param amsshipCargoTransferResult
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/amsshipcargotransferresults/editCargoTransferResult")
    Map<String, Object> editCargoTransferResult(@RequestBody Map<String, Object> amsshipCargoTransferResult);

    /**
     * 查询货权转移
     *
     * @param cargoTransferResultId
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/amsshipcargotransferresults/selectByCargoTranferResultId/{cargoTransferResultId}")
    Map<String, Object> selectByCargoTranferResultId(@PathVariable("cargoTransferResultId") Integer cargoTransferResultId);

    /**
     * 展示提货委托
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/amsshipdeliveryattorneys/getAmsshipDeliveryAttroneyList")
    Map<String, Object> getAmsshipDeliveryAttroneyList(@RequestBody(required = false) Map<String, Object> mapValue,
                                                 @RequestParam Integer pageNum,
                                                 @RequestParam Integer pageSize,
                                                 @RequestParam Integer apiId,
                                                 @RequestParam Integer status,
                                                       @RequestParam String con);

    /**
     * 新增提货委托
     *
     * @param map
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/amsshipdeliveryattorneys/insertshipDeliveryAttorney")
    Map<String, Object> insertshipDeliveryAttorney(@RequestBody(required = false) Map<String, Object> map);

    /**
     * 逻辑删除提货委托
     *
     * @param attorneyId
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/amsshipdeliveryattorneys/deleteByAttorneyId/{attorneyId}")
    Map<String, Object> deleteByAttorneyId(@PathVariable("attorneyId") Integer attorneyId);

    /**
     * 修改提货委托
     *
     * @param amsshipDeliveryAttorney
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/amsshipdeliveryattorneys/editDeliveryAttroney")
    Map<String, Object> editDeliveryAttroney(@RequestBody Map<String, Object> amsshipDeliveryAttorney);

    /**
     * 查询提货委托
     *
     * @param attorneyId
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/amsshipdeliveryattorneys/getDeliveryAttorneyId/{attorneyId}")
    Map<String, Object> getDeliveryAttorneyId(@PathVariable("attorneyId") Integer attorneyId);

    /**
     * 下发提货委托
     *
     * @param attorneyId
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/amsshipdeliveryattorneys/sendDeliveryAttorneyStatus/{attorneyId}")
    Map<String, Object> sendDeliveryAttorneyStatus(@PathVariable("attorneyId") Integer attorneyId);

    /**
     * 展示放货通知
     *
     * @param mapValue
     * @param pageNum
     * @param pageSize
     * @param apiId
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/amsshipdeliverynotices/getshipDeliveryNoticeList")
    Map<String, Object> getshipDeliveryNoticeList(@RequestBody(required = false) Map<String, Object> mapValue,
                                            @RequestParam Integer pageNum,
                                            @RequestParam Integer pageSize,
                                            @RequestParam Integer apiId,
                                            @RequestParam Integer  status);

    /**
     * 新增放货通知
     *
     * @param amsshipDeliveryNotice
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/amsshipdeliverynotices/insertDeliveryNotice")
    Map<String, Object> insertDeliveryNotice(@RequestBody Map<String, Object> amsshipDeliveryNotice);

    /**
     * 逻辑删除放货通知
     *
     * @param noticeId
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/amsshipdeliverynotices/deleteByNoticeId/{noticeId}")
    Map<String, Object> deleteByNoticeId(@PathVariable("noticeId") Integer noticeId);

    /**
     * 修改放货通知
     *
     * @param amsshipDeliveryNotice
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/amsshipdeliverynotices/editDeliveryNotice")
    Map<String, Object> editDeliveryNotice(@RequestBody Map<String, Object> amsshipDeliveryNotice);

    /**
     * 查询放货通知
     *
     * @param noticeId
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/amsshipdeliverynotices/selectByNoticeId/{noticeId}")
    Map<String, Object> selectByNoticeId(@PathVariable("noticeId") Integer noticeId);

    /**
     * 下发放货通知
     *
     * @param noticeId
     * @return
     */
    @PostMapping(value = "/api/v1/shipTms/amsshipdeliverynotices/sendDeliveryNotice/{noticeId}")
    Map<String, Object> sendDeliveryNotice(@PathVariable("noticeId") Integer noticeId);

    //船舶动态表
    @PostMapping("api/v1/shipTms/shipdynamics/selectAllShipDynamaics")
    Map<String, Object> selectAllShipDynamaics();


    //获取合同水分值，实装吨位，水分吨位
    @PostMapping("api/v1/shipTms/tmsshipwaterqualityresults/getMoistureAndInstallations")
    Map<String,Object> getMoistureAndInstallations(Map<String,Object> map);

    //    模糊查询江船名
    @PostMapping(value = "/api/v1/shipTms/dilbatchs/getShipNameList")
    Map<String, Object> getShipNameList(@RequestParam(value = "state")String state);

}