package com.steerinfo.dil.service.impl;
import com.alibaba.fastjson.JSON;
import com.steerinfo.dil.feign.JoinFeign;
import com.steerinfo.dil.mapper.UniversalMapper;
import com.steerinfo.dil.service.UniversalService;
import com.steerinfo.dil.util.ESUtil;
import org.apache.commons.codec.digest.DigestUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.io.InputStream;
import java.math.BigDecimal;
import java.sql.Blob;
import java.sql.SQLException;
import java.util.*;

/**
 * @ author    :TXF
 * @ time      :2021/10/19 18:05
 */

@Service
public class UniversalServiceImpl implements UniversalService {

    @Resource
    private UniversalMapper universalMapper;

    @Autowired
    private JoinFeign joinFeign;

    @Autowired
    private ESUtil esUtil;
    /**
     * 打印提货单
     * @param orderNumber 运输订单号
     * @return
     */
    @Override
    public Map<String, Object> printTiHuoDan(String orderNumber) {

        //查询订单信息
        Map<String, Object> tiHuoDanMap = universalMapper.getTiHuoDan(orderNumber);
        //查询该订单下的所有装车信息
        List<Map<String, Object>> oomMes = universalMapper.getOOMMes(orderNumber);
        tiHuoDanMap.put("loadMes", oomMes);
        return tiHuoDanMap;
    }


    /**
     * 查询路段顺序及当前路段顺序号
     * @param map
     * @return
     */
    @Override
    public Map<String, Object> getNowLineMes(Map<String, Object> map) {

        return null;
    }

//    @Override
//    public  List<String> getWarrantyAndPrint(String orderNumber) {
//        List<Map<String,Object>> warrantyCode = universalMapper.getWarranty(orderNumber);
//        List<String> list = new ArrayList<>();
//        String content = null;
//        for(Map<String,Object> code:warrantyCode){
//            Blob blob = (Blob) code.get("warrantyCode");
//            try {
//               content = new String(blob.getBytes((long)1, (int)blob.length()));
//               String string = content.substring(0,content.length()-2);
//               System.out.println(string);
//               list.add(string);
//            } catch (SQLException throwables) {
//                throwables.printStackTrace();
//            }
//        }
//
//        return list;
//    }

    @Override
    public List<String> getWarranty(String orderNumber) {
        List<String> list = new ArrayList<>();
        //回传金蝶
        //根据orderNumber查询
        Map<String,Object> map = getWarrantyToES(orderNumber);
        String string = null;
        try{
             string = joinFeign.sendWarranty(map);
            Map<String,Object> waMap = JSON.parseObject(string);
            //成功
            if(waMap.get("kdStatus").equals("1")){
                List<Map<String,Object>> reportList = (List<Map<String,Object>>) waMap.get("qcReportList");
                Map<String,Object> map1 = reportList.get(0);
                Iterator<Map.Entry<String, Object>> it = map1.entrySet().iterator();
                Map.Entry<String,Object> entry;
                while(it.hasNext()){
                    entry =  it.next();
                    String value = (String) entry.getValue();
                    list.add(value);
                }
            }    //失败
            else{
                list.add("-1");
            }
        }catch (NullPointerException e){
            e.printStackTrace();
            list.add("-2");
        }
        return list;
    }

    @Override
    public List<String> getTest(Map<String, Object> map) {
        List<String> list = new ArrayList<>();
        //成功
        if(map.get("kdStatus").equals("1")){
            List<Map<String,Object>> reportList = (List<Map<String,Object>>) map.get("qcReportList");
            Map<String,Object> map1 = reportList.get(0);
            Iterator<Map.Entry<String, Object>> it = map1.entrySet().iterator();
            Map.Entry<String,Object> entry;
            while(it.hasNext()){
                entry =  it.next();
                String value = (String) entry.getValue();
                list.add(value);
            }
        }//失败
        else{
            list.add("0");
        }
        return list;
    }

    //出库与金蝶打通接口(获得质保书)
    public Map<String,Object> getWarrantyToES(String orderNumber) {
        Map<String, Object> input = new HashMap<>();
        Map<String, Object> head = universalMapper.selectNum(orderNumber);
        input.put("head", head);
        List<Map<String, Object>> mapList = universalMapper.selectOutbound(orderNumber);
        input.put("entries",mapList);
        Map<String,Object> totalMap = esUtil.getTotalMap();
        //组装报文
        totalMap.put("input",input);
        return totalMap;
    }


    /**
     * sha1加密字符串
     * @param text
     * @return
     */
    public String sha1DigestUtils(String text){
        return DigestUtils.sha1Hex(text);
    }

    /**
     * 根据收货客户查询承运商
      */
    public Map<String, Object> getCarrierByConsignee(Map<String, Object> mapValue){
        String isSelfMention = (String) mapValue.get("isSelfMention");
        String consigneeName = (String) mapValue.get("consigneeName");
        Map<String, Object> map = new HashMap<>();
        if (isSelfMention.equals("是")) {
            map = universalMapper.getCarrierByConsignee(consigneeName);
        }
        else {
            map.put("carrierId",null);
            map.put("carrierName",null);
        }
        return map;
    }

    /**
     *
     * @param mapValue
     * @return
     */
    public Map<String, Object> isInCapacityCarrier(Map<String, Object> mapValue) {
        BigDecimal capacityCarrierId = universalMapper.isInCapacityCarrier(mapValue);
        BigDecimal capacityId = universalMapper.isInCapacity(mapValue);
        Map<String,Object> map = new HashMap<>();
        map.put("capacityCarrierId",capacityCarrierId);
        map.put("capacityId",capacityId);
        return map;
    }

    public List<Map<String, Object>> getPortId() {
        return universalMapper.getPortId();
    }

    //获取订单号以及订单号下的物资
    public Map<String, Object> getOrderNumber(String num) {
        return universalMapper.getOrderNumber(num);
    }

    public List<Map<String, Object>> getCapacityNumber(String num) {
        return universalMapper.getCapacityNumber(num);
    }


    public List<Map<String, Object>> getMaterialIdByOrderId(Integer orderId) {
        return universalMapper.getMaterialIdByOrderId(orderId);
    }
}
